# swagger-client
These are the docs for the curia platform API. To test, generate an authorization token first.

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 3.12.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import curia.api.swagger_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import curia.api.swagger_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import curia.api.swagger_client
from curia.api.swagger_client.rest import ApiException
from pprint import pprint

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['Api-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Api-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CohortsApi(swagger_client.ApiClient(configuration))
id = 'id_example' # str | 

try:
    # Submit Cohort Queries
    api_response = api_instance.cohort_controller_query(id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CohortsApi->cohort_controller_query: %s\n" % e)

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['Api-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Api-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CohortsApi(swagger_client.ApiClient(configuration))
id = 'id_example' # str | 

try:
    # Generate SQL queries for cohort
    api_response = api_instance.cohort_controller_sql(id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CohortsApi->cohort_controller_sql: %s\n" % e)

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['Api-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Api-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CohortsApi(swagger_client.ApiClient(configuration))
body = swagger_client.CreateManyCohortDto() # CreateManyCohortDto | 

try:
    # Create multiple Cohorts
    api_response = api_instance.create_many_base_cohort_controller_cohort(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CohortsApi->create_many_base_cohort_controller_cohort: %s\n" % e)

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['Api-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Api-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CohortsApi(swagger_client.ApiClient(configuration))
body = swagger_client.Cohort() # Cohort | 

try:
    # Create a single Cohort
    api_response = api_instance.create_one_base_cohort_controller_cohort(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CohortsApi->create_one_base_cohort_controller_cohort: %s\n" % e)

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['Api-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Api-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CohortsApi(swagger_client.ApiClient(configuration))
id = 'id_example' # str | 

try:
    # Delete a single Cohort
    api_instance.delete_one_base_cohort_controller_cohort(id)
except ApiException as e:
    print("Exception when calling CohortsApi->delete_one_base_cohort_controller_cohort: %s\n" % e)

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['Api-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Api-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CohortsApi(swagger_client.ApiClient(configuration))
fields = ['fields_example'] # list[str] | Selects resource fields. <a href=\"https://github.com/nestjsx/crud/wiki/Requests#select\" target=\"_blank\">Docs</a> (optional)
s = 's_example' # str | Adds search condition. <a href=\"https://github.com/nestjsx/crud/wiki/Requests#search\" target=\"_blank\">Docs</a> (optional)
filter = ['filter_example'] # list[str] | Adds filter condition. <a href=\"https://github.com/nestjsx/crud/wiki/Requests#filter\" target=\"_blank\">Docs</a> (optional)
_or = ['_or_example'] # list[str] | Adds OR condition. <a href=\"https://github.com/nestjsx/crud/wiki/Requests#or\" target=\"_blank\">Docs</a> (optional)
sort = ['sort_example'] # list[str] | Adds sort by field. <a href=\"https://github.com/nestjsx/crud/wiki/Requests#sort\" target=\"_blank\">Docs</a> (optional)
join = ['join_example'] # list[str] | Adds relational resources. <a href=\"https://github.com/nestjsx/crud/wiki/Requests#join\" target=\"_blank\">Docs</a> (optional)
limit = 56 # int | Limit amount of resources. <a href=\"https://github.com/nestjsx/crud/wiki/Requests#limit\" target=\"_blank\">Docs</a> (optional)
offset = 56 # int | Offset amount of resources. <a href=\"https://github.com/nestjsx/crud/wiki/Requests#offset\" target=\"_blank\">Docs</a> (optional)
page = 56 # int | Page portion of resources. <a href=\"https://github.com/nestjsx/crud/wiki/Requests#page\" target=\"_blank\">Docs</a> (optional)
cache = 56 # int | Reset cache (if was enabled). <a href=\"https://github.com/nestjsx/crud/wiki/Requests#cache\" target=\"_blank\">Docs</a> (optional)

try:
    # Retrieve multiple Cohorts
    api_response = api_instance.get_many_base_cohort_controller_cohort(fields=fields, s=s, filter=filter, _or=_or, sort=sort, join=join, limit=limit, offset=offset, page=page, cache=cache)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CohortsApi->get_many_base_cohort_controller_cohort: %s\n" % e)

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['Api-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Api-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CohortsApi(swagger_client.ApiClient(configuration))
id = 'id_example' # str | 
fields = ['fields_example'] # list[str] | Selects resource fields. <a href=\"https://github.com/nestjsx/crud/wiki/Requests#select\" target=\"_blank\">Docs</a> (optional)
join = ['join_example'] # list[str] | Adds relational resources. <a href=\"https://github.com/nestjsx/crud/wiki/Requests#join\" target=\"_blank\">Docs</a> (optional)
cache = 56 # int | Reset cache (if was enabled). <a href=\"https://github.com/nestjsx/crud/wiki/Requests#cache\" target=\"_blank\">Docs</a> (optional)

try:
    # Retrieve a single Cohort
    api_response = api_instance.get_one_base_cohort_controller_cohort(id, fields=fields, join=join, cache=cache)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CohortsApi->get_one_base_cohort_controller_cohort: %s\n" % e)

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['Api-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Api-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CohortsApi(swagger_client.ApiClient(configuration))
body = swagger_client.Cohort() # Cohort | 
id = 'id_example' # str | 

try:
    # Replace a single Cohort
    api_response = api_instance.replace_one_base_cohort_controller_cohort(body, id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CohortsApi->replace_one_base_cohort_controller_cohort: %s\n" % e)

# Configure API key authorization: api_key
configuration = swagger_client.Configuration()
configuration.api_key['Api-Key'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['Api-Key'] = 'Bearer'

# create an instance of the API class
api_instance = swagger_client.CohortsApi(swagger_client.ApiClient(configuration))
body = swagger_client.Cohort() # Cohort | 
id = 'id_example' # str | 

try:
    # Update a single Cohort
    api_response = api_instance.update_one_base_cohort_controller_cohort(body, id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CohortsApi->update_one_base_cohort_controller_cohort: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.curia.ai*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CohortsApi* | [**cohort_controller_query**](docs/CohortsApi.md#cohort_controller_query) | **GET** /cohorts/{id}/query | Submit Cohort Queries
*CohortsApi* | [**cohort_controller_sql**](docs/CohortsApi.md#cohort_controller_sql) | **GET** /cohorts/{id}/sql | Generate SQL queries for cohort
*CohortsApi* | [**create_many_base_cohort_controller_cohort**](docs/CohortsApi.md#create_many_base_cohort_controller_cohort) | **POST** /cohorts/bulk | Create multiple Cohorts
*CohortsApi* | [**create_one_base_cohort_controller_cohort**](docs/CohortsApi.md#create_one_base_cohort_controller_cohort) | **POST** /cohorts | Create a single Cohort
*CohortsApi* | [**delete_one_base_cohort_controller_cohort**](docs/CohortsApi.md#delete_one_base_cohort_controller_cohort) | **DELETE** /cohorts/{id} | Delete a single Cohort
*CohortsApi* | [**get_many_base_cohort_controller_cohort**](docs/CohortsApi.md#get_many_base_cohort_controller_cohort) | **GET** /cohorts | Retrieve multiple Cohorts
*CohortsApi* | [**get_one_base_cohort_controller_cohort**](docs/CohortsApi.md#get_one_base_cohort_controller_cohort) | **GET** /cohorts/{id} | Retrieve a single Cohort
*CohortsApi* | [**replace_one_base_cohort_controller_cohort**](docs/CohortsApi.md#replace_one_base_cohort_controller_cohort) | **PUT** /cohorts/{id} | Replace a single Cohort
*CohortsApi* | [**update_one_base_cohort_controller_cohort**](docs/CohortsApi.md#update_one_base_cohort_controller_cohort) | **PATCH** /cohorts/{id} | Update a single Cohort
*DataQueriesApi* | [**create_many_base_data_query_controller_data_query**](docs/DataQueriesApi.md#create_many_base_data_query_controller_data_query) | **POST** /data-queries/bulk | Create multiple DataQueries
*DataQueriesApi* | [**create_one_base_data_query_controller_data_query**](docs/DataQueriesApi.md#create_one_base_data_query_controller_data_query) | **POST** /data-queries | Create a single DataQuery
*DataQueriesApi* | [**data_query_controller_execute**](docs/DataQueriesApi.md#data_query_controller_execute) | **GET** /data-queries/{id}/execute | Execute Data Query
*DataQueriesApi* | [**delete_one_base_data_query_controller_data_query**](docs/DataQueriesApi.md#delete_one_base_data_query_controller_data_query) | **DELETE** /data-queries/{id} | Delete a single DataQuery
*DataQueriesApi* | [**get_many_base_data_query_controller_data_query**](docs/DataQueriesApi.md#get_many_base_data_query_controller_data_query) | **GET** /data-queries | Retrieve multiple DataQueries
*DataQueriesApi* | [**get_one_base_data_query_controller_data_query**](docs/DataQueriesApi.md#get_one_base_data_query_controller_data_query) | **GET** /data-queries/{id} | Retrieve a single DataQuery
*DataQueriesApi* | [**replace_one_base_data_query_controller_data_query**](docs/DataQueriesApi.md#replace_one_base_data_query_controller_data_query) | **PUT** /data-queries/{id} | Replace a single DataQuery
*DataQueriesApi* | [**update_one_base_data_query_controller_data_query**](docs/DataQueriesApi.md#update_one_base_data_query_controller_data_query) | **PATCH** /data-queries/{id} | Update a single DataQuery
*DataStoresApi* | [**create_many_base_data_store_controller_data_store**](docs/DataStoresApi.md#create_many_base_data_store_controller_data_store) | **POST** /data-stores/bulk | Create multiple DataStores
*DataStoresApi* | [**create_one_base_data_store_controller_data_store**](docs/DataStoresApi.md#create_one_base_data_store_controller_data_store) | **POST** /data-stores | Create a single DataStore
*DataStoresApi* | [**delete_one_base_data_store_controller_data_store**](docs/DataStoresApi.md#delete_one_base_data_store_controller_data_store) | **DELETE** /data-stores/{id} | Delete a single DataStore
*DataStoresApi* | [**get_many_base_data_store_controller_data_store**](docs/DataStoresApi.md#get_many_base_data_store_controller_data_store) | **GET** /data-stores | Retrieve multiple DataStores
*DataStoresApi* | [**get_one_base_data_store_controller_data_store**](docs/DataStoresApi.md#get_one_base_data_store_controller_data_store) | **GET** /data-stores/{id} | Retrieve a single DataStore
*DataStoresApi* | [**replace_one_base_data_store_controller_data_store**](docs/DataStoresApi.md#replace_one_base_data_store_controller_data_store) | **PUT** /data-stores/{id} | Replace a single DataStore
*DataStoresApi* | [**update_one_base_data_store_controller_data_store**](docs/DataStoresApi.md#update_one_base_data_store_controller_data_store) | **PATCH** /data-stores/{id} | Update a single DataStore
*DataTablesApi* | [**get_many_base_data_table_controller_data_table**](docs/DataTablesApi.md#get_many_base_data_table_controller_data_table) | **GET** /data-tables | Retrieve multiple DataTables
*DataTablesApi* | [**get_one_base_data_table_controller_data_table**](docs/DataTablesApi.md#get_one_base_data_table_controller_data_table) | **GET** /data-tables/{id} | Retrieve a single DataTable
*DatabasesApi* | [**database_controller_clean_database**](docs/DatabasesApi.md#database_controller_clean_database) | **GET** /databases/clean | Remove temp tables from Databases
*DatabasesApi* | [**database_controller_sync**](docs/DatabasesApi.md#database_controller_sync) | **GET** /databases/sync | Sync Databases
*DatabasesApi* | [**get_many_base_database_controller_database**](docs/DatabasesApi.md#get_many_base_database_controller_database) | **GET** /databases | Retrieve multiple Databases
*DatabasesApi* | [**get_one_base_database_controller_database**](docs/DatabasesApi.md#get_one_base_database_controller_database) | **GET** /databases/{id} | Retrieve a single Database
*DatasetColumnsApi* | [**create_many_base_dataset_column_controller_dataset_column**](docs/DatasetColumnsApi.md#create_many_base_dataset_column_controller_dataset_column) | **POST** /dataset-columns/bulk | Create multiple DatasetColumns
*DatasetColumnsApi* | [**create_one_base_dataset_column_controller_dataset_column**](docs/DatasetColumnsApi.md#create_one_base_dataset_column_controller_dataset_column) | **POST** /dataset-columns | Create a single DatasetColumn
*DatasetColumnsApi* | [**delete_one_base_dataset_column_controller_dataset_column**](docs/DatasetColumnsApi.md#delete_one_base_dataset_column_controller_dataset_column) | **DELETE** /dataset-columns/{id} | Delete a single DatasetColumn
*DatasetColumnsApi* | [**get_many_base_dataset_column_controller_dataset_column**](docs/DatasetColumnsApi.md#get_many_base_dataset_column_controller_dataset_column) | **GET** /dataset-columns | Retrieve multiple DatasetColumns
*DatasetColumnsApi* | [**get_one_base_dataset_column_controller_dataset_column**](docs/DatasetColumnsApi.md#get_one_base_dataset_column_controller_dataset_column) | **GET** /dataset-columns/{id} | Retrieve a single DatasetColumn
*DatasetColumnsApi* | [**replace_one_base_dataset_column_controller_dataset_column**](docs/DatasetColumnsApi.md#replace_one_base_dataset_column_controller_dataset_column) | **PUT** /dataset-columns/{id} | Replace a single DatasetColumn
*DatasetColumnsApi* | [**update_one_base_dataset_column_controller_dataset_column**](docs/DatasetColumnsApi.md#update_one_base_dataset_column_controller_dataset_column) | **PATCH** /dataset-columns/{id} | Update a single DatasetColumn
*DatasetsApi* | [**create_many_base_dataset_controller_dataset**](docs/DatasetsApi.md#create_many_base_dataset_controller_dataset) | **POST** /datasets/bulk | Create multiple Datasets
*DatasetsApi* | [**create_one_base_dataset_controller_dataset**](docs/DatasetsApi.md#create_one_base_dataset_controller_dataset) | **POST** /datasets | Create a single Dataset
*DatasetsApi* | [**dataset_controller_calculate_stats**](docs/DatasetsApi.md#dataset_controller_calculate_stats) | **GET** /datasets/{id}/calculate-stats | Calculate dataset stats
*DatasetsApi* | [**dataset_controller_download_dataset**](docs/DatasetsApi.md#dataset_controller_download_dataset) | **GET** /datasets/{id}/download | Download dataset
*DatasetsApi* | [**dataset_controller_get_datasets_by_tag**](docs/DatasetsApi.md#dataset_controller_get_datasets_by_tag) | **GET** /datasets/tag/{tag} | Retrieve datasets by tag
*DatasetsApi* | [**dataset_controller_internal_download_dataset**](docs/DatasetsApi.md#dataset_controller_internal_download_dataset) | **GET** /datasets/internal/{id}/download | Download dataset
*DatasetsApi* | [**dataset_controller_sync_to_snowflake**](docs/DatasetsApi.md#dataset_controller_sync_to_snowflake) | **POST** /datasets/{id}/snowflake-upload | Copy the dataset into snowflake
*DatasetsApi* | [**dataset_controller_upload**](docs/DatasetsApi.md#dataset_controller_upload) | **POST** /datasets/upload | Upload dataset
*DatasetsApi* | [**dataset_controller_upload_abort**](docs/DatasetsApi.md#dataset_controller_upload_abort) | **POST** /datasets/upload-large-cancel | cancel multipart upload for large dataset
*DatasetsApi* | [**dataset_controller_upload_finish**](docs/DatasetsApi.md#dataset_controller_upload_finish) | **POST** /datasets/upload-large-complete | complete upload for large dataset using multipart upload
*DatasetsApi* | [**dataset_controller_upload_multipart_start**](docs/DatasetsApi.md#dataset_controller_upload_multipart_start) | **POST** /datasets/upload-large-start | Initiate upload for large dataset using multipart upload
*DatasetsApi* | [**delete_one_base_dataset_controller_dataset**](docs/DatasetsApi.md#delete_one_base_dataset_controller_dataset) | **DELETE** /datasets/{id} | Delete a single Dataset
*DatasetsApi* | [**get_many_base_dataset_controller_dataset**](docs/DatasetsApi.md#get_many_base_dataset_controller_dataset) | **GET** /datasets | Retrieve multiple Datasets
*DatasetsApi* | [**get_one_base_dataset_controller_dataset**](docs/DatasetsApi.md#get_one_base_dataset_controller_dataset) | **GET** /datasets/{id} | Retrieve a single Dataset
*DatasetsApi* | [**replace_one_base_dataset_controller_dataset**](docs/DatasetsApi.md#replace_one_base_dataset_controller_dataset) | **PUT** /datasets/{id} | Replace a single Dataset
*DatasetsApi* | [**update_one_base_dataset_controller_dataset**](docs/DatasetsApi.md#update_one_base_dataset_controller_dataset) | **PATCH** /datasets/{id} | Update a single Dataset
*FeatureServicesApi* | [**create_many_base_feature_service_controller_feature_service**](docs/FeatureServicesApi.md#create_many_base_feature_service_controller_feature_service) | **POST** /feature-services/bulk | Create multiple FeatureServices
*FeatureServicesApi* | [**create_one_base_feature_service_controller_feature_service**](docs/FeatureServicesApi.md#create_one_base_feature_service_controller_feature_service) | **POST** /feature-services | Create a single FeatureService
*FeatureServicesApi* | [**delete_one_base_feature_service_controller_feature_service**](docs/FeatureServicesApi.md#delete_one_base_feature_service_controller_feature_service) | **DELETE** /feature-services/{id} | Delete a single FeatureService
*FeatureServicesApi* | [**get_many_base_feature_service_controller_feature_service**](docs/FeatureServicesApi.md#get_many_base_feature_service_controller_feature_service) | **GET** /feature-services | Retrieve multiple FeatureServices
*FeatureServicesApi* | [**get_one_base_feature_service_controller_feature_service**](docs/FeatureServicesApi.md#get_one_base_feature_service_controller_feature_service) | **GET** /feature-services/{id} | Retrieve a single FeatureService
*FeatureServicesApi* | [**replace_one_base_feature_service_controller_feature_service**](docs/FeatureServicesApi.md#replace_one_base_feature_service_controller_feature_service) | **PUT** /feature-services/{id} | Replace a single FeatureService
*FeatureServicesApi* | [**update_one_base_feature_service_controller_feature_service**](docs/FeatureServicesApi.md#update_one_base_feature_service_controller_feature_service) | **PATCH** /feature-services/{id} | Update a single FeatureService
*FeatureStoresApi* | [**create_many_base_feature_store_controller_feature_store**](docs/FeatureStoresApi.md#create_many_base_feature_store_controller_feature_store) | **POST** /feature-stores/bulk | Create multiple FeatureStores
*FeatureStoresApi* | [**create_one_base_feature_store_controller_feature_store**](docs/FeatureStoresApi.md#create_one_base_feature_store_controller_feature_store) | **POST** /feature-stores | Create a single FeatureStore
*FeatureStoresApi* | [**delete_one_base_feature_store_controller_feature_store**](docs/FeatureStoresApi.md#delete_one_base_feature_store_controller_feature_store) | **DELETE** /feature-stores/{id} | Delete a single FeatureStore
*FeatureStoresApi* | [**get_many_base_feature_store_controller_feature_store**](docs/FeatureStoresApi.md#get_many_base_feature_store_controller_feature_store) | **GET** /feature-stores | Retrieve multiple FeatureStores
*FeatureStoresApi* | [**get_one_base_feature_store_controller_feature_store**](docs/FeatureStoresApi.md#get_one_base_feature_store_controller_feature_store) | **GET** /feature-stores/{id} | Retrieve a single FeatureStore
*FeatureStoresApi* | [**replace_one_base_feature_store_controller_feature_store**](docs/FeatureStoresApi.md#replace_one_base_feature_store_controller_feature_store) | **PUT** /feature-stores/{id} | Replace a single FeatureStore
*FeatureStoresApi* | [**update_one_base_feature_store_controller_feature_store**](docs/FeatureStoresApi.md#update_one_base_feature_store_controller_feature_store) | **PATCH** /feature-stores/{id} | Update a single FeatureStore
*FeatureTablesApi* | [**create_many_base_feature_table_controller_feature_table**](docs/FeatureTablesApi.md#create_many_base_feature_table_controller_feature_table) | **POST** /feature-tables/bulk | Create multiple FeatureTables
*FeatureTablesApi* | [**create_one_base_feature_table_controller_feature_table**](docs/FeatureTablesApi.md#create_one_base_feature_table_controller_feature_table) | **POST** /feature-tables | Create a single FeatureTable
*FeatureTablesApi* | [**delete_one_base_feature_table_controller_feature_table**](docs/FeatureTablesApi.md#delete_one_base_feature_table_controller_feature_table) | **DELETE** /feature-tables/{id} | Delete a single FeatureTable
*FeatureTablesApi* | [**get_many_base_feature_table_controller_feature_table**](docs/FeatureTablesApi.md#get_many_base_feature_table_controller_feature_table) | **GET** /feature-tables | Retrieve multiple FeatureTables
*FeatureTablesApi* | [**get_one_base_feature_table_controller_feature_table**](docs/FeatureTablesApi.md#get_one_base_feature_table_controller_feature_table) | **GET** /feature-tables/{id} | Retrieve a single FeatureTable
*FeatureTablesApi* | [**replace_one_base_feature_table_controller_feature_table**](docs/FeatureTablesApi.md#replace_one_base_feature_table_controller_feature_table) | **PUT** /feature-tables/{id} | Replace a single FeatureTable
*FeatureTablesApi* | [**update_one_base_feature_table_controller_feature_table**](docs/FeatureTablesApi.md#update_one_base_feature_table_controller_feature_table) | **PATCH** /feature-tables/{id} | Update a single FeatureTable
*FeatureViewsApi* | [**create_many_base_feature_view_controller_feature_view**](docs/FeatureViewsApi.md#create_many_base_feature_view_controller_feature_view) | **POST** /feature-views/bulk | Create multiple FeatureViews
*FeatureViewsApi* | [**create_one_base_feature_view_controller_feature_view**](docs/FeatureViewsApi.md#create_one_base_feature_view_controller_feature_view) | **POST** /feature-views | Create a single FeatureView
*FeatureViewsApi* | [**delete_one_base_feature_view_controller_feature_view**](docs/FeatureViewsApi.md#delete_one_base_feature_view_controller_feature_view) | **DELETE** /feature-views/{id} | Delete a single FeatureView
*FeatureViewsApi* | [**get_many_base_feature_view_controller_feature_view**](docs/FeatureViewsApi.md#get_many_base_feature_view_controller_feature_view) | **GET** /feature-views | Retrieve multiple FeatureViews
*FeatureViewsApi* | [**get_one_base_feature_view_controller_feature_view**](docs/FeatureViewsApi.md#get_one_base_feature_view_controller_feature_view) | **GET** /feature-views/{id} | Retrieve a single FeatureView
*FeatureViewsApi* | [**replace_one_base_feature_view_controller_feature_view**](docs/FeatureViewsApi.md#replace_one_base_feature_view_controller_feature_view) | **PUT** /feature-views/{id} | Replace a single FeatureView
*FeatureViewsApi* | [**update_one_base_feature_view_controller_feature_view**](docs/FeatureViewsApi.md#update_one_base_feature_view_controller_feature_view) | **PATCH** /feature-views/{id} | Update a single FeatureView
*FeaturesApi* | [**create_many_base_feature_controller_feature**](docs/FeaturesApi.md#create_many_base_feature_controller_feature) | **POST** /features/bulk | Create multiple Features
*FeaturesApi* | [**create_one_base_feature_controller_feature**](docs/FeaturesApi.md#create_one_base_feature_controller_feature) | **POST** /features | Create a single Feature
*FeaturesApi* | [**delete_one_base_feature_controller_feature**](docs/FeaturesApi.md#delete_one_base_feature_controller_feature) | **DELETE** /features/{id} | Delete a single Feature
*FeaturesApi* | [**get_many_base_feature_controller_feature**](docs/FeaturesApi.md#get_many_base_feature_controller_feature) | **GET** /features | Retrieve multiple Features
*FeaturesApi* | [**get_one_base_feature_controller_feature**](docs/FeaturesApi.md#get_one_base_feature_controller_feature) | **GET** /features/{id} | Retrieve a single Feature
*FeaturesApi* | [**replace_one_base_feature_controller_feature**](docs/FeaturesApi.md#replace_one_base_feature_controller_feature) | **PUT** /features/{id} | Replace a single Feature
*FeaturesApi* | [**update_one_base_feature_controller_feature**](docs/FeaturesApi.md#update_one_base_feature_controller_feature) | **PATCH** /features/{id} | Update a single Feature
*InternalApi* | [**create_many_base_feature_controller_feature**](docs/InternalApi.md#create_many_base_feature_controller_feature) | **POST** /features/bulk | Create multiple Features
*InternalApi* | [**create_one_base_feature_controller_feature**](docs/InternalApi.md#create_one_base_feature_controller_feature) | **POST** /features | Create a single Feature
*InternalApi* | [**dataset_controller_internal_download_dataset**](docs/InternalApi.md#dataset_controller_internal_download_dataset) | **GET** /datasets/internal/{id}/download | Download dataset
*InternalApi* | [**delete_one_base_feature_controller_feature**](docs/InternalApi.md#delete_one_base_feature_controller_feature) | **DELETE** /features/{id} | Delete a single Feature
*InternalApi* | [**get_many_base_feature_controller_feature**](docs/InternalApi.md#get_many_base_feature_controller_feature) | **GET** /features | Retrieve multiple Features
*InternalApi* | [**get_one_base_feature_controller_feature**](docs/InternalApi.md#get_one_base_feature_controller_feature) | **GET** /features/{id} | Retrieve a single Feature
*InternalApi* | [**organization_setting_controller_get_unscoped_organization_settings**](docs/InternalApi.md#organization_setting_controller_get_unscoped_organization_settings) | **GET** /organization-settings/unscoped | Retrieve all organization settings
*InternalApi* | [**replace_one_base_feature_controller_feature**](docs/InternalApi.md#replace_one_base_feature_controller_feature) | **PUT** /features/{id} | Replace a single Feature
*InternalApi* | [**update_one_base_feature_controller_feature**](docs/InternalApi.md#update_one_base_feature_controller_feature) | **PATCH** /features/{id} | Update a single Feature
*ModelJobOutputsApi* | [**create_many_base_model_job_output_controller_model_job_output**](docs/ModelJobOutputsApi.md#create_many_base_model_job_output_controller_model_job_output) | **POST** /model-job-outputs/bulk | Create multiple ModelJobOutputs
*ModelJobOutputsApi* | [**create_one_base_model_job_output_controller_model_job_output**](docs/ModelJobOutputsApi.md#create_one_base_model_job_output_controller_model_job_output) | **POST** /model-job-outputs | Create a single ModelJobOutput
*ModelJobOutputsApi* | [**delete_one_base_model_job_output_controller_model_job_output**](docs/ModelJobOutputsApi.md#delete_one_base_model_job_output_controller_model_job_output) | **DELETE** /model-job-outputs/{id} | Delete a single ModelJobOutput
*ModelJobOutputsApi* | [**get_many_base_model_job_output_controller_model_job_output**](docs/ModelJobOutputsApi.md#get_many_base_model_job_output_controller_model_job_output) | **GET** /model-job-outputs | Retrieve multiple ModelJobOutputs
*ModelJobOutputsApi* | [**get_one_base_model_job_output_controller_model_job_output**](docs/ModelJobOutputsApi.md#get_one_base_model_job_output_controller_model_job_output) | **GET** /model-job-outputs/{id} | Retrieve a single ModelJobOutput
*ModelJobOutputsApi* | [**replace_one_base_model_job_output_controller_model_job_output**](docs/ModelJobOutputsApi.md#replace_one_base_model_job_output_controller_model_job_output) | **PUT** /model-job-outputs/{id} | Replace a single ModelJobOutput
*ModelJobOutputsApi* | [**update_one_base_model_job_output_controller_model_job_output**](docs/ModelJobOutputsApi.md#update_one_base_model_job_output_controller_model_job_output) | **PATCH** /model-job-outputs/{id} | Update a single ModelJobOutput
*ModelJobStatusesApi* | [**create_one_base_model_job_status_controller_model_job_status**](docs/ModelJobStatusesApi.md#create_one_base_model_job_status_controller_model_job_status) | **POST** /model-job-statuses | Create a single ModelJobStatus
*ModelJobStatusesApi* | [**get_many_base_model_job_status_controller_model_job_status**](docs/ModelJobStatusesApi.md#get_many_base_model_job_status_controller_model_job_status) | **GET** /model-job-statuses | Retrieve multiple ModelJobStatuses
*ModelJobStatusesApi* | [**get_one_base_model_job_status_controller_model_job_status**](docs/ModelJobStatusesApi.md#get_one_base_model_job_status_controller_model_job_status) | **GET** /model-job-statuses/{id} | Retrieve a single ModelJobStatus
*ModelJobStatusesApi* | [**model_job_status_controller_bulk_update_project_id**](docs/ModelJobStatusesApi.md#model_job_status_controller_bulk_update_project_id) | **POST** /model-job-statuses/bulk-update-project-id | 
*ModelJobsApi* | [**create_many_base_model_job_controller_model_job**](docs/ModelJobsApi.md#create_many_base_model_job_controller_model_job) | **POST** /model-jobs/bulk | Create multiple ModelJobs
*ModelJobsApi* | [**create_one_base_model_job_controller_model_job**](docs/ModelJobsApi.md#create_one_base_model_job_controller_model_job) | **POST** /model-jobs | Create a single ModelJob
*ModelJobsApi* | [**delete_one_base_model_job_controller_model_job**](docs/ModelJobsApi.md#delete_one_base_model_job_controller_model_job) | **DELETE** /model-jobs/{id} | Delete a single ModelJob
*ModelJobsApi* | [**get_many_base_model_job_controller_model_job**](docs/ModelJobsApi.md#get_many_base_model_job_controller_model_job) | **GET** /model-jobs | Retrieve multiple ModelJobs
*ModelJobsApi* | [**get_one_base_model_job_controller_model_job**](docs/ModelJobsApi.md#get_one_base_model_job_controller_model_job) | **GET** /model-jobs/{id} | Retrieve a single ModelJob
*ModelJobsApi* | [**model_job_controller_generate_odhq**](docs/ModelJobsApi.md#model_job_controller_generate_odhq) | **GET** /model-jobs/{id}/generate-odhq | Execute Outcome Distribution Histogram Query
*ModelJobsApi* | [**model_job_controller_get_predictions_data**](docs/ModelJobsApi.md#model_job_controller_get_predictions_data) | **GET** /model-jobs/{id}/predictions | Retrieve model job predictions
*ModelJobsApi* | [**model_job_controller_start**](docs/ModelJobsApi.md#model_job_controller_start) | **GET** /model-jobs/{id}/start | Start model job
*ModelJobsApi* | [**model_job_controller_stop**](docs/ModelJobsApi.md#model_job_controller_stop) | **GET** /model-jobs/{id}/stop | Stop Model job
*ModelJobsApi* | [**replace_one_base_model_job_controller_model_job**](docs/ModelJobsApi.md#replace_one_base_model_job_controller_model_job) | **PUT** /model-jobs/{id} | Replace a single ModelJob
*ModelJobsApi* | [**update_one_base_model_job_controller_model_job**](docs/ModelJobsApi.md#update_one_base_model_job_controller_model_job) | **PATCH** /model-jobs/{id} | Update a single ModelJob
*ModelPopulationsApi* | [**create_many_base_model_population_controller_model_population**](docs/ModelPopulationsApi.md#create_many_base_model_population_controller_model_population) | **POST** /model-populations/bulk | Create multiple ModelPopulations
*ModelPopulationsApi* | [**create_one_base_model_population_controller_model_population**](docs/ModelPopulationsApi.md#create_one_base_model_population_controller_model_population) | **POST** /model-populations | Create a single ModelPopulation
*ModelPopulationsApi* | [**delete_one_base_model_population_controller_model_population**](docs/ModelPopulationsApi.md#delete_one_base_model_population_controller_model_population) | **DELETE** /model-populations/{id} | Delete a single ModelPopulation
*ModelPopulationsApi* | [**get_many_base_model_population_controller_model_population**](docs/ModelPopulationsApi.md#get_many_base_model_population_controller_model_population) | **GET** /model-populations | Retrieve multiple ModelPopulations
*ModelPopulationsApi* | [**get_one_base_model_population_controller_model_population**](docs/ModelPopulationsApi.md#get_one_base_model_population_controller_model_population) | **GET** /model-populations/{id} | Retrieve a single ModelPopulation
*ModelPopulationsApi* | [**model_population_controller_queue_query**](docs/ModelPopulationsApi.md#model_population_controller_queue_query) | **POST** /model-populations/{id}/queue-query/{type} | Queue model population query
*ModelPopulationsApi* | [**replace_one_base_model_population_controller_model_population**](docs/ModelPopulationsApi.md#replace_one_base_model_population_controller_model_population) | **PUT** /model-populations/{id} | Replace a single ModelPopulation
*ModelPopulationsApi* | [**update_one_base_model_population_controller_model_population**](docs/ModelPopulationsApi.md#update_one_base_model_population_controller_model_population) | **PATCH** /model-populations/{id} | Update a single ModelPopulation
*ModelsApi* | [**create_many_base_model_controller_model**](docs/ModelsApi.md#create_many_base_model_controller_model) | **POST** /models/bulk | Create multiple Models
*ModelsApi* | [**create_one_base_model_controller_model**](docs/ModelsApi.md#create_one_base_model_controller_model) | **POST** /models | Create a single Model
*ModelsApi* | [**delete_one_base_model_controller_model**](docs/ModelsApi.md#delete_one_base_model_controller_model) | **DELETE** /models/{id} | Delete a single Model
*ModelsApi* | [**get_many_base_model_controller_model**](docs/ModelsApi.md#get_many_base_model_controller_model) | **GET** /models | Retrieve multiple Models
*ModelsApi* | [**get_one_base_model_controller_model**](docs/ModelsApi.md#get_one_base_model_controller_model) | **GET** /models/{id} | Retrieve a single Model
*ModelsApi* | [**model_controller_clone_model**](docs/ModelsApi.md#model_controller_clone_model) | **POST** /models/{id}/clone | Clone existing model
*ModelsApi* | [**model_controller_get_many_and_join_metadata**](docs/ModelsApi.md#model_controller_get_many_and_join_metadata) | **GET** /models/detailed | Retrieve model and metadata
*ModelsApi* | [**model_controller_get_recent_models**](docs/ModelsApi.md#model_controller_get_recent_models) | **GET** /models/recent | Retrieve recent models
*ModelsApi* | [**replace_one_base_model_controller_model**](docs/ModelsApi.md#replace_one_base_model_controller_model) | **PUT** /models/{id} | Replace a single Model
*ModelsApi* | [**update_one_base_model_controller_model**](docs/ModelsApi.md#update_one_base_model_controller_model) | **PATCH** /models/{id} | Update a single Model
*OrganizationSettingsApi* | [**create_many_base_organization_setting_controller_organization_setting**](docs/OrganizationSettingsApi.md#create_many_base_organization_setting_controller_organization_setting) | **POST** /organization-settings/bulk | Create multiple OrganizationSettings
*OrganizationSettingsApi* | [**create_one_base_organization_setting_controller_organization_setting**](docs/OrganizationSettingsApi.md#create_one_base_organization_setting_controller_organization_setting) | **POST** /organization-settings | Create a single OrganizationSetting
*OrganizationSettingsApi* | [**delete_one_base_organization_setting_controller_organization_setting**](docs/OrganizationSettingsApi.md#delete_one_base_organization_setting_controller_organization_setting) | **DELETE** /organization-settings/{id} | Delete a single OrganizationSetting
*OrganizationSettingsApi* | [**get_many_base_organization_setting_controller_organization_setting**](docs/OrganizationSettingsApi.md#get_many_base_organization_setting_controller_organization_setting) | **GET** /organization-settings | Retrieve multiple OrganizationSettings
*OrganizationSettingsApi* | [**get_one_base_organization_setting_controller_organization_setting**](docs/OrganizationSettingsApi.md#get_one_base_organization_setting_controller_organization_setting) | **GET** /organization-settings/{id} | Retrieve a single OrganizationSetting
*OrganizationSettingsApi* | [**organization_setting_controller_get_unscoped_organization_settings**](docs/OrganizationSettingsApi.md#organization_setting_controller_get_unscoped_organization_settings) | **GET** /organization-settings/unscoped | Retrieve all organization settings
*OrganizationSettingsApi* | [**organization_setting_controller_get_versions**](docs/OrganizationSettingsApi.md#organization_setting_controller_get_versions) | **GET** /organization-settings/versions | Retrieve container versions
*OrganizationSettingsApi* | [**replace_one_base_organization_setting_controller_organization_setting**](docs/OrganizationSettingsApi.md#replace_one_base_organization_setting_controller_organization_setting) | **PUT** /organization-settings/{id} | Replace a single OrganizationSetting
*OrganizationSettingsApi* | [**update_one_base_organization_setting_controller_organization_setting**](docs/OrganizationSettingsApi.md#update_one_base_organization_setting_controller_organization_setting) | **PATCH** /organization-settings/{id} | Update a single OrganizationSetting
*OrganizationsApi* | [**create_many_base_organizations_controller_organization**](docs/OrganizationsApi.md#create_many_base_organizations_controller_organization) | **POST** /organizations/bulk | Create multiple Organizations
*OrganizationsApi* | [**create_one_base_organizations_controller_organization**](docs/OrganizationsApi.md#create_one_base_organizations_controller_organization) | **POST** /organizations | Create a single Organization
*OrganizationsApi* | [**delete_one_base_organizations_controller_organization**](docs/OrganizationsApi.md#delete_one_base_organizations_controller_organization) | **DELETE** /organizations/{id} | Delete a single Organization
*OrganizationsApi* | [**get_many_base_organizations_controller_organization**](docs/OrganizationsApi.md#get_many_base_organizations_controller_organization) | **GET** /organizations | Retrieve multiple Organizations
*OrganizationsApi* | [**get_one_base_organizations_controller_organization**](docs/OrganizationsApi.md#get_one_base_organizations_controller_organization) | **GET** /organizations/{id} | Retrieve a single Organization
*OrganizationsApi* | [**replace_one_base_organizations_controller_organization**](docs/OrganizationsApi.md#replace_one_base_organizations_controller_organization) | **PUT** /organizations/{id} | Replace a single Organization
*OrganizationsApi* | [**update_one_base_organizations_controller_organization**](docs/OrganizationsApi.md#update_one_base_organizations_controller_organization) | **PATCH** /organizations/{id} | Update a single Organization
*PlatformApi* | [**cohort_controller_query**](docs/PlatformApi.md#cohort_controller_query) | **GET** /cohorts/{id}/query | Submit Cohort Queries
*PlatformApi* | [**cohort_controller_sql**](docs/PlatformApi.md#cohort_controller_sql) | **GET** /cohorts/{id}/sql | Generate SQL queries for cohort
*PlatformApi* | [**create_many_base_cohort_controller_cohort**](docs/PlatformApi.md#create_many_base_cohort_controller_cohort) | **POST** /cohorts/bulk | Create multiple Cohorts
*PlatformApi* | [**create_many_base_data_query_controller_data_query**](docs/PlatformApi.md#create_many_base_data_query_controller_data_query) | **POST** /data-queries/bulk | Create multiple DataQueries
*PlatformApi* | [**create_many_base_data_store_controller_data_store**](docs/PlatformApi.md#create_many_base_data_store_controller_data_store) | **POST** /data-stores/bulk | Create multiple DataStores
*PlatformApi* | [**create_many_base_dataset_column_controller_dataset_column**](docs/PlatformApi.md#create_many_base_dataset_column_controller_dataset_column) | **POST** /dataset-columns/bulk | Create multiple DatasetColumns
*PlatformApi* | [**create_many_base_dataset_controller_dataset**](docs/PlatformApi.md#create_many_base_dataset_controller_dataset) | **POST** /datasets/bulk | Create multiple Datasets
*PlatformApi* | [**create_many_base_feature_controller_feature**](docs/PlatformApi.md#create_many_base_feature_controller_feature) | **POST** /features/bulk | Create multiple Features
*PlatformApi* | [**create_many_base_feature_service_controller_feature_service**](docs/PlatformApi.md#create_many_base_feature_service_controller_feature_service) | **POST** /feature-services/bulk | Create multiple FeatureServices
*PlatformApi* | [**create_many_base_feature_store_controller_feature_store**](docs/PlatformApi.md#create_many_base_feature_store_controller_feature_store) | **POST** /feature-stores/bulk | Create multiple FeatureStores
*PlatformApi* | [**create_many_base_feature_table_controller_feature_table**](docs/PlatformApi.md#create_many_base_feature_table_controller_feature_table) | **POST** /feature-tables/bulk | Create multiple FeatureTables
*PlatformApi* | [**create_many_base_feature_view_controller_feature_view**](docs/PlatformApi.md#create_many_base_feature_view_controller_feature_view) | **POST** /feature-views/bulk | Create multiple FeatureViews
*PlatformApi* | [**create_many_base_model_controller_model**](docs/PlatformApi.md#create_many_base_model_controller_model) | **POST** /models/bulk | Create multiple Models
*PlatformApi* | [**create_many_base_model_job_controller_model_job**](docs/PlatformApi.md#create_many_base_model_job_controller_model_job) | **POST** /model-jobs/bulk | Create multiple ModelJobs
*PlatformApi* | [**create_many_base_model_job_output_controller_model_job_output**](docs/PlatformApi.md#create_many_base_model_job_output_controller_model_job_output) | **POST** /model-job-outputs/bulk | Create multiple ModelJobOutputs
*PlatformApi* | [**create_many_base_model_population_controller_model_population**](docs/PlatformApi.md#create_many_base_model_population_controller_model_population) | **POST** /model-populations/bulk | Create multiple ModelPopulations
*PlatformApi* | [**create_many_base_organization_setting_controller_organization_setting**](docs/PlatformApi.md#create_many_base_organization_setting_controller_organization_setting) | **POST** /organization-settings/bulk | Create multiple OrganizationSettings
*PlatformApi* | [**create_many_base_organizations_controller_organization**](docs/PlatformApi.md#create_many_base_organizations_controller_organization) | **POST** /organizations/bulk | Create multiple Organizations
*PlatformApi* | [**create_many_base_population_store_controller_population_store**](docs/PlatformApi.md#create_many_base_population_store_controller_population_store) | **POST** /population-stores/bulk | Create multiple PopulationStores
*PlatformApi* | [**create_many_base_project_controller_project**](docs/PlatformApi.md#create_many_base_project_controller_project) | **POST** /projects/bulk | Create multiple Projects
*PlatformApi* | [**create_many_base_project_member_controller_project_member**](docs/PlatformApi.md#create_many_base_project_member_controller_project_member) | **POST** /project-members/bulk | Create multiple ProjectMembers
*PlatformApi* | [**create_many_base_scheduler_controller_scheduler**](docs/PlatformApi.md#create_many_base_scheduler_controller_scheduler) | **POST** /schedulers/bulk | Create multiple Schedulers
*PlatformApi* | [**create_many_base_task_controller_task**](docs/PlatformApi.md#create_many_base_task_controller_task) | **POST** /tasks/bulk | Create multiple Tasks
*PlatformApi* | [**create_many_base_task_execution_controller_task_execution**](docs/PlatformApi.md#create_many_base_task_execution_controller_task_execution) | **POST** /task-executions/bulk | Create multiple TaskExecutions
*PlatformApi* | [**create_many_base_task_execution_status_controller_task_execution_status**](docs/PlatformApi.md#create_many_base_task_execution_status_controller_task_execution_status) | **POST** /task-execution-statuses/bulk | Create multiple TaskExecutionStatuses
*PlatformApi* | [**create_many_base_tecton_feature_controller_tecton_feature**](docs/PlatformApi.md#create_many_base_tecton_feature_controller_tecton_feature) | **POST** /tecton-features/bulk | Create multiple TectonFeatures
*PlatformApi* | [**create_many_base_user_favorite_controller_user_favorite**](docs/PlatformApi.md#create_many_base_user_favorite_controller_user_favorite) | **POST** /user-favorites/bulk | Create multiple UserFavorites
*PlatformApi* | [**create_many_base_workflow_controller_workflow**](docs/PlatformApi.md#create_many_base_workflow_controller_workflow) | **POST** /workflows/bulk | Create multiple Workflows
*PlatformApi* | [**create_many_base_workflow_execution_controller_workflow_execution**](docs/PlatformApi.md#create_many_base_workflow_execution_controller_workflow_execution) | **POST** /workflow-executions/bulk | Create multiple WorkflowExecutions
*PlatformApi* | [**create_many_base_workflow_execution_spec_controller_workflow_execution_spec**](docs/PlatformApi.md#create_many_base_workflow_execution_spec_controller_workflow_execution_spec) | **POST** /workflow-execution-specs/bulk | Create multiple WorkflowExecutionSpecs
*PlatformApi* | [**create_many_base_workflow_template_controller_workflow_template**](docs/PlatformApi.md#create_many_base_workflow_template_controller_workflow_template) | **POST** /workflow-templates/bulk | Create multiple WorkflowTemplates
*PlatformApi* | [**create_one_base_cohort_controller_cohort**](docs/PlatformApi.md#create_one_base_cohort_controller_cohort) | **POST** /cohorts | Create a single Cohort
*PlatformApi* | [**create_one_base_data_query_controller_data_query**](docs/PlatformApi.md#create_one_base_data_query_controller_data_query) | **POST** /data-queries | Create a single DataQuery
*PlatformApi* | [**create_one_base_data_store_controller_data_store**](docs/PlatformApi.md#create_one_base_data_store_controller_data_store) | **POST** /data-stores | Create a single DataStore
*PlatformApi* | [**create_one_base_dataset_column_controller_dataset_column**](docs/PlatformApi.md#create_one_base_dataset_column_controller_dataset_column) | **POST** /dataset-columns | Create a single DatasetColumn
*PlatformApi* | [**create_one_base_dataset_controller_dataset**](docs/PlatformApi.md#create_one_base_dataset_controller_dataset) | **POST** /datasets | Create a single Dataset
*PlatformApi* | [**create_one_base_feature_controller_feature**](docs/PlatformApi.md#create_one_base_feature_controller_feature) | **POST** /features | Create a single Feature
*PlatformApi* | [**create_one_base_feature_service_controller_feature_service**](docs/PlatformApi.md#create_one_base_feature_service_controller_feature_service) | **POST** /feature-services | Create a single FeatureService
*PlatformApi* | [**create_one_base_feature_store_controller_feature_store**](docs/PlatformApi.md#create_one_base_feature_store_controller_feature_store) | **POST** /feature-stores | Create a single FeatureStore
*PlatformApi* | [**create_one_base_feature_table_controller_feature_table**](docs/PlatformApi.md#create_one_base_feature_table_controller_feature_table) | **POST** /feature-tables | Create a single FeatureTable
*PlatformApi* | [**create_one_base_feature_view_controller_feature_view**](docs/PlatformApi.md#create_one_base_feature_view_controller_feature_view) | **POST** /feature-views | Create a single FeatureView
*PlatformApi* | [**create_one_base_model_controller_model**](docs/PlatformApi.md#create_one_base_model_controller_model) | **POST** /models | Create a single Model
*PlatformApi* | [**create_one_base_model_job_controller_model_job**](docs/PlatformApi.md#create_one_base_model_job_controller_model_job) | **POST** /model-jobs | Create a single ModelJob
*PlatformApi* | [**create_one_base_model_job_output_controller_model_job_output**](docs/PlatformApi.md#create_one_base_model_job_output_controller_model_job_output) | **POST** /model-job-outputs | Create a single ModelJobOutput
*PlatformApi* | [**create_one_base_model_job_status_controller_model_job_status**](docs/PlatformApi.md#create_one_base_model_job_status_controller_model_job_status) | **POST** /model-job-statuses | Create a single ModelJobStatus
*PlatformApi* | [**create_one_base_model_population_controller_model_population**](docs/PlatformApi.md#create_one_base_model_population_controller_model_population) | **POST** /model-populations | Create a single ModelPopulation
*PlatformApi* | [**create_one_base_organization_setting_controller_organization_setting**](docs/PlatformApi.md#create_one_base_organization_setting_controller_organization_setting) | **POST** /organization-settings | Create a single OrganizationSetting
*PlatformApi* | [**create_one_base_organizations_controller_organization**](docs/PlatformApi.md#create_one_base_organizations_controller_organization) | **POST** /organizations | Create a single Organization
*PlatformApi* | [**create_one_base_population_store_controller_population_store**](docs/PlatformApi.md#create_one_base_population_store_controller_population_store) | **POST** /population-stores | Create a single PopulationStore
*PlatformApi* | [**create_one_base_project_controller_project**](docs/PlatformApi.md#create_one_base_project_controller_project) | **POST** /projects | Create a single Project
*PlatformApi* | [**create_one_base_project_member_controller_project_member**](docs/PlatformApi.md#create_one_base_project_member_controller_project_member) | **POST** /project-members | Create a single ProjectMember
*PlatformApi* | [**create_one_base_scheduler_controller_scheduler**](docs/PlatformApi.md#create_one_base_scheduler_controller_scheduler) | **POST** /schedulers | Create a single Scheduler
*PlatformApi* | [**create_one_base_task_controller_task**](docs/PlatformApi.md#create_one_base_task_controller_task) | **POST** /tasks | Create a single Task
*PlatformApi* | [**create_one_base_task_execution_controller_task_execution**](docs/PlatformApi.md#create_one_base_task_execution_controller_task_execution) | **POST** /task-executions | Create a single TaskExecution
*PlatformApi* | [**create_one_base_task_execution_status_controller_task_execution_status**](docs/PlatformApi.md#create_one_base_task_execution_status_controller_task_execution_status) | **POST** /task-execution-statuses | Create a single TaskExecutionStatus
*PlatformApi* | [**create_one_base_tecton_feature_controller_tecton_feature**](docs/PlatformApi.md#create_one_base_tecton_feature_controller_tecton_feature) | **POST** /tecton-features | Create a single TectonFeature
*PlatformApi* | [**create_one_base_user_favorite_controller_user_favorite**](docs/PlatformApi.md#create_one_base_user_favorite_controller_user_favorite) | **POST** /user-favorites | Create a single UserFavorite
*PlatformApi* | [**create_one_base_workflow_controller_workflow**](docs/PlatformApi.md#create_one_base_workflow_controller_workflow) | **POST** /workflows | Create a single Workflow
*PlatformApi* | [**create_one_base_workflow_execution_controller_workflow_execution**](docs/PlatformApi.md#create_one_base_workflow_execution_controller_workflow_execution) | **POST** /workflow-executions | Create a single WorkflowExecution
*PlatformApi* | [**create_one_base_workflow_execution_spec_controller_workflow_execution_spec**](docs/PlatformApi.md#create_one_base_workflow_execution_spec_controller_workflow_execution_spec) | **POST** /workflow-execution-specs | Create a single WorkflowExecutionSpec
*PlatformApi* | [**create_one_base_workflow_execution_status_controller_workflow_execution_status**](docs/PlatformApi.md#create_one_base_workflow_execution_status_controller_workflow_execution_status) | **POST** /workflow-execution-statuses | Create a single WorkflowExecutionStatus
*PlatformApi* | [**create_one_base_workflow_template_controller_workflow_template**](docs/PlatformApi.md#create_one_base_workflow_template_controller_workflow_template) | **POST** /workflow-templates | Create a single WorkflowTemplate
*PlatformApi* | [**data_query_controller_execute**](docs/PlatformApi.md#data_query_controller_execute) | **GET** /data-queries/{id}/execute | Execute Data Query
*PlatformApi* | [**database_controller_clean_database**](docs/PlatformApi.md#database_controller_clean_database) | **GET** /databases/clean | Remove temp tables from Databases
*PlatformApi* | [**database_controller_sync**](docs/PlatformApi.md#database_controller_sync) | **GET** /databases/sync | Sync Databases
*PlatformApi* | [**dataset_controller_calculate_stats**](docs/PlatformApi.md#dataset_controller_calculate_stats) | **GET** /datasets/{id}/calculate-stats | Calculate dataset stats
*PlatformApi* | [**dataset_controller_calculate_stats_0**](docs/PlatformApi.md#dataset_controller_calculate_stats_0) | **GET** /datasets/{id}/calculate-stats | Calculate dataset stats
*PlatformApi* | [**dataset_controller_download_dataset**](docs/PlatformApi.md#dataset_controller_download_dataset) | **GET** /datasets/{id}/download | Download dataset
*PlatformApi* | [**dataset_controller_download_dataset_0**](docs/PlatformApi.md#dataset_controller_download_dataset_0) | **GET** /datasets/{id}/download | Download dataset
*PlatformApi* | [**dataset_controller_get_datasets_by_tag**](docs/PlatformApi.md#dataset_controller_get_datasets_by_tag) | **GET** /datasets/tag/{tag} | Retrieve datasets by tag
*PlatformApi* | [**dataset_controller_get_datasets_by_tag_0**](docs/PlatformApi.md#dataset_controller_get_datasets_by_tag_0) | **GET** /datasets/tag/{tag} | Retrieve datasets by tag
*PlatformApi* | [**dataset_controller_internal_download_dataset**](docs/PlatformApi.md#dataset_controller_internal_download_dataset) | **GET** /datasets/internal/{id}/download | Download dataset
*PlatformApi* | [**dataset_controller_sync_to_snowflake**](docs/PlatformApi.md#dataset_controller_sync_to_snowflake) | **POST** /datasets/{id}/snowflake-upload | Copy the dataset into snowflake
*PlatformApi* | [**dataset_controller_sync_to_snowflake_0**](docs/PlatformApi.md#dataset_controller_sync_to_snowflake_0) | **POST** /datasets/{id}/snowflake-upload | Copy the dataset into snowflake
*PlatformApi* | [**dataset_controller_upload**](docs/PlatformApi.md#dataset_controller_upload) | **POST** /datasets/upload | Upload dataset
*PlatformApi* | [**dataset_controller_upload_0**](docs/PlatformApi.md#dataset_controller_upload_0) | **POST** /datasets/upload | Upload dataset
*PlatformApi* | [**dataset_controller_upload_abort**](docs/PlatformApi.md#dataset_controller_upload_abort) | **POST** /datasets/upload-large-cancel | cancel multipart upload for large dataset
*PlatformApi* | [**dataset_controller_upload_abort_0**](docs/PlatformApi.md#dataset_controller_upload_abort_0) | **POST** /datasets/upload-large-cancel | cancel multipart upload for large dataset
*PlatformApi* | [**dataset_controller_upload_finish**](docs/PlatformApi.md#dataset_controller_upload_finish) | **POST** /datasets/upload-large-complete | complete upload for large dataset using multipart upload
*PlatformApi* | [**dataset_controller_upload_finish_0**](docs/PlatformApi.md#dataset_controller_upload_finish_0) | **POST** /datasets/upload-large-complete | complete upload for large dataset using multipart upload
*PlatformApi* | [**dataset_controller_upload_multipart_start**](docs/PlatformApi.md#dataset_controller_upload_multipart_start) | **POST** /datasets/upload-large-start | Initiate upload for large dataset using multipart upload
*PlatformApi* | [**dataset_controller_upload_multipart_start_0**](docs/PlatformApi.md#dataset_controller_upload_multipart_start_0) | **POST** /datasets/upload-large-start | Initiate upload for large dataset using multipart upload
*PlatformApi* | [**delete_one_base_cohort_controller_cohort**](docs/PlatformApi.md#delete_one_base_cohort_controller_cohort) | **DELETE** /cohorts/{id} | Delete a single Cohort
*PlatformApi* | [**delete_one_base_data_query_controller_data_query**](docs/PlatformApi.md#delete_one_base_data_query_controller_data_query) | **DELETE** /data-queries/{id} | Delete a single DataQuery
*PlatformApi* | [**delete_one_base_data_store_controller_data_store**](docs/PlatformApi.md#delete_one_base_data_store_controller_data_store) | **DELETE** /data-stores/{id} | Delete a single DataStore
*PlatformApi* | [**delete_one_base_dataset_column_controller_dataset_column**](docs/PlatformApi.md#delete_one_base_dataset_column_controller_dataset_column) | **DELETE** /dataset-columns/{id} | Delete a single DatasetColumn
*PlatformApi* | [**delete_one_base_dataset_controller_dataset**](docs/PlatformApi.md#delete_one_base_dataset_controller_dataset) | **DELETE** /datasets/{id} | Delete a single Dataset
*PlatformApi* | [**delete_one_base_dataset_controller_dataset_0**](docs/PlatformApi.md#delete_one_base_dataset_controller_dataset_0) | **DELETE** /datasets/{id} | Delete a single Dataset
*PlatformApi* | [**delete_one_base_feature_controller_feature**](docs/PlatformApi.md#delete_one_base_feature_controller_feature) | **DELETE** /features/{id} | Delete a single Feature
*PlatformApi* | [**delete_one_base_feature_service_controller_feature_service**](docs/PlatformApi.md#delete_one_base_feature_service_controller_feature_service) | **DELETE** /feature-services/{id} | Delete a single FeatureService
*PlatformApi* | [**delete_one_base_feature_store_controller_feature_store**](docs/PlatformApi.md#delete_one_base_feature_store_controller_feature_store) | **DELETE** /feature-stores/{id} | Delete a single FeatureStore
*PlatformApi* | [**delete_one_base_feature_table_controller_feature_table**](docs/PlatformApi.md#delete_one_base_feature_table_controller_feature_table) | **DELETE** /feature-tables/{id} | Delete a single FeatureTable
*PlatformApi* | [**delete_one_base_feature_view_controller_feature_view**](docs/PlatformApi.md#delete_one_base_feature_view_controller_feature_view) | **DELETE** /feature-views/{id} | Delete a single FeatureView
*PlatformApi* | [**delete_one_base_model_controller_model**](docs/PlatformApi.md#delete_one_base_model_controller_model) | **DELETE** /models/{id} | Delete a single Model
*PlatformApi* | [**delete_one_base_model_job_controller_model_job**](docs/PlatformApi.md#delete_one_base_model_job_controller_model_job) | **DELETE** /model-jobs/{id} | Delete a single ModelJob
*PlatformApi* | [**delete_one_base_model_job_output_controller_model_job_output**](docs/PlatformApi.md#delete_one_base_model_job_output_controller_model_job_output) | **DELETE** /model-job-outputs/{id} | Delete a single ModelJobOutput
*PlatformApi* | [**delete_one_base_model_population_controller_model_population**](docs/PlatformApi.md#delete_one_base_model_population_controller_model_population) | **DELETE** /model-populations/{id} | Delete a single ModelPopulation
*PlatformApi* | [**delete_one_base_organization_setting_controller_organization_setting**](docs/PlatformApi.md#delete_one_base_organization_setting_controller_organization_setting) | **DELETE** /organization-settings/{id} | Delete a single OrganizationSetting
*PlatformApi* | [**delete_one_base_organizations_controller_organization**](docs/PlatformApi.md#delete_one_base_organizations_controller_organization) | **DELETE** /organizations/{id} | Delete a single Organization
*PlatformApi* | [**delete_one_base_population_store_controller_population_store**](docs/PlatformApi.md#delete_one_base_population_store_controller_population_store) | **DELETE** /population-stores/{id} | Delete a single PopulationStore
*PlatformApi* | [**delete_one_base_project_controller_project**](docs/PlatformApi.md#delete_one_base_project_controller_project) | **DELETE** /projects/{id} | Delete a single Project
*PlatformApi* | [**delete_one_base_project_member_controller_project_member**](docs/PlatformApi.md#delete_one_base_project_member_controller_project_member) | **DELETE** /project-members/{id} | Delete a single ProjectMember
*PlatformApi* | [**delete_one_base_scheduler_controller_scheduler**](docs/PlatformApi.md#delete_one_base_scheduler_controller_scheduler) | **DELETE** /schedulers/{id} | Delete a single Scheduler
*PlatformApi* | [**delete_one_base_task_controller_task**](docs/PlatformApi.md#delete_one_base_task_controller_task) | **DELETE** /tasks/{id} | Delete a single Task
*PlatformApi* | [**delete_one_base_task_execution_controller_task_execution**](docs/PlatformApi.md#delete_one_base_task_execution_controller_task_execution) | **DELETE** /task-executions/{id} | Delete a single TaskExecution
*PlatformApi* | [**delete_one_base_task_execution_status_controller_task_execution_status**](docs/PlatformApi.md#delete_one_base_task_execution_status_controller_task_execution_status) | **DELETE** /task-execution-statuses/{id} | Delete a single TaskExecutionStatus
*PlatformApi* | [**delete_one_base_tecton_feature_controller_tecton_feature**](docs/PlatformApi.md#delete_one_base_tecton_feature_controller_tecton_feature) | **DELETE** /tecton-features/{id} | Delete a single TectonFeature
*PlatformApi* | [**delete_one_base_user_favorite_controller_user_favorite**](docs/PlatformApi.md#delete_one_base_user_favorite_controller_user_favorite) | **DELETE** /user-favorites/{id} | Delete a single UserFavorite
*PlatformApi* | [**delete_one_base_workflow_controller_workflow**](docs/PlatformApi.md#delete_one_base_workflow_controller_workflow) | **DELETE** /workflows/{id} | Delete a single Workflow
*PlatformApi* | [**delete_one_base_workflow_execution_controller_workflow_execution**](docs/PlatformApi.md#delete_one_base_workflow_execution_controller_workflow_execution) | **DELETE** /workflow-executions/{id} | Delete a single WorkflowExecution
*PlatformApi* | [**delete_one_base_workflow_execution_spec_controller_workflow_execution_spec**](docs/PlatformApi.md#delete_one_base_workflow_execution_spec_controller_workflow_execution_spec) | **DELETE** /workflow-execution-specs/{id} | Delete a single WorkflowExecutionSpec
*PlatformApi* | [**delete_one_base_workflow_template_controller_workflow_template**](docs/PlatformApi.md#delete_one_base_workflow_template_controller_workflow_template) | **DELETE** /workflow-templates/{id} | Delete a single WorkflowTemplate
*PlatformApi* | [**get_many_base_cohort_controller_cohort**](docs/PlatformApi.md#get_many_base_cohort_controller_cohort) | **GET** /cohorts | Retrieve multiple Cohorts
*PlatformApi* | [**get_many_base_data_query_controller_data_query**](docs/PlatformApi.md#get_many_base_data_query_controller_data_query) | **GET** /data-queries | Retrieve multiple DataQueries
*PlatformApi* | [**get_many_base_data_store_controller_data_store**](docs/PlatformApi.md#get_many_base_data_store_controller_data_store) | **GET** /data-stores | Retrieve multiple DataStores
*PlatformApi* | [**get_many_base_data_table_controller_data_table**](docs/PlatformApi.md#get_many_base_data_table_controller_data_table) | **GET** /data-tables | Retrieve multiple DataTables
*PlatformApi* | [**get_many_base_database_controller_database**](docs/PlatformApi.md#get_many_base_database_controller_database) | **GET** /databases | Retrieve multiple Databases
*PlatformApi* | [**get_many_base_dataset_column_controller_dataset_column**](docs/PlatformApi.md#get_many_base_dataset_column_controller_dataset_column) | **GET** /dataset-columns | Retrieve multiple DatasetColumns
*PlatformApi* | [**get_many_base_dataset_controller_dataset**](docs/PlatformApi.md#get_many_base_dataset_controller_dataset) | **GET** /datasets | Retrieve multiple Datasets
*PlatformApi* | [**get_many_base_feature_controller_feature**](docs/PlatformApi.md#get_many_base_feature_controller_feature) | **GET** /features | Retrieve multiple Features
*PlatformApi* | [**get_many_base_feature_service_controller_feature_service**](docs/PlatformApi.md#get_many_base_feature_service_controller_feature_service) | **GET** /feature-services | Retrieve multiple FeatureServices
*PlatformApi* | [**get_many_base_feature_store_controller_feature_store**](docs/PlatformApi.md#get_many_base_feature_store_controller_feature_store) | **GET** /feature-stores | Retrieve multiple FeatureStores
*PlatformApi* | [**get_many_base_feature_table_controller_feature_table**](docs/PlatformApi.md#get_many_base_feature_table_controller_feature_table) | **GET** /feature-tables | Retrieve multiple FeatureTables
*PlatformApi* | [**get_many_base_feature_view_controller_feature_view**](docs/PlatformApi.md#get_many_base_feature_view_controller_feature_view) | **GET** /feature-views | Retrieve multiple FeatureViews
*PlatformApi* | [**get_many_base_model_controller_model**](docs/PlatformApi.md#get_many_base_model_controller_model) | **GET** /models | Retrieve multiple Models
*PlatformApi* | [**get_many_base_model_job_controller_model_job**](docs/PlatformApi.md#get_many_base_model_job_controller_model_job) | **GET** /model-jobs | Retrieve multiple ModelJobs
*PlatformApi* | [**get_many_base_model_job_output_controller_model_job_output**](docs/PlatformApi.md#get_many_base_model_job_output_controller_model_job_output) | **GET** /model-job-outputs | Retrieve multiple ModelJobOutputs
*PlatformApi* | [**get_many_base_model_job_status_controller_model_job_status**](docs/PlatformApi.md#get_many_base_model_job_status_controller_model_job_status) | **GET** /model-job-statuses | Retrieve multiple ModelJobStatuses
*PlatformApi* | [**get_many_base_model_population_controller_model_population**](docs/PlatformApi.md#get_many_base_model_population_controller_model_population) | **GET** /model-populations | Retrieve multiple ModelPopulations
*PlatformApi* | [**get_many_base_organization_setting_controller_organization_setting**](docs/PlatformApi.md#get_many_base_organization_setting_controller_organization_setting) | **GET** /organization-settings | Retrieve multiple OrganizationSettings
*PlatformApi* | [**get_many_base_organizations_controller_organization**](docs/PlatformApi.md#get_many_base_organizations_controller_organization) | **GET** /organizations | Retrieve multiple Organizations
*PlatformApi* | [**get_many_base_population_store_controller_population_store**](docs/PlatformApi.md#get_many_base_population_store_controller_population_store) | **GET** /population-stores | Retrieve multiple PopulationStores
*PlatformApi* | [**get_many_base_project_controller_project**](docs/PlatformApi.md#get_many_base_project_controller_project) | **GET** /projects | Retrieve multiple Projects
*PlatformApi* | [**get_many_base_project_member_controller_project_member**](docs/PlatformApi.md#get_many_base_project_member_controller_project_member) | **GET** /project-members | Retrieve multiple ProjectMembers
*PlatformApi* | [**get_many_base_scheduler_controller_scheduler**](docs/PlatformApi.md#get_many_base_scheduler_controller_scheduler) | **GET** /schedulers | Retrieve multiple Schedulers
*PlatformApi* | [**get_many_base_task_controller_task**](docs/PlatformApi.md#get_many_base_task_controller_task) | **GET** /tasks | Retrieve multiple Tasks
*PlatformApi* | [**get_many_base_task_execution_controller_task_execution**](docs/PlatformApi.md#get_many_base_task_execution_controller_task_execution) | **GET** /task-executions | Retrieve multiple TaskExecutions
*PlatformApi* | [**get_many_base_task_execution_status_controller_task_execution_status**](docs/PlatformApi.md#get_many_base_task_execution_status_controller_task_execution_status) | **GET** /task-execution-statuses | Retrieve multiple TaskExecutionStatuses
*PlatformApi* | [**get_many_base_tecton_feature_controller_tecton_feature**](docs/PlatformApi.md#get_many_base_tecton_feature_controller_tecton_feature) | **GET** /tecton-features | Retrieve multiple TectonFeatures
*PlatformApi* | [**get_many_base_user_audit_trail_controller_user_audit_trail**](docs/PlatformApi.md#get_many_base_user_audit_trail_controller_user_audit_trail) | **GET** /user-audit-trail | Retrieve multiple UserAuditTrails
*PlatformApi* | [**get_many_base_user_favorite_controller_user_favorite**](docs/PlatformApi.md#get_many_base_user_favorite_controller_user_favorite) | **GET** /user-favorites | Retrieve multiple UserFavorites
*PlatformApi* | [**get_many_base_workflow_controller_workflow**](docs/PlatformApi.md#get_many_base_workflow_controller_workflow) | **GET** /workflows | Retrieve multiple Workflows
*PlatformApi* | [**get_many_base_workflow_execution_controller_workflow_execution**](docs/PlatformApi.md#get_many_base_workflow_execution_controller_workflow_execution) | **GET** /workflow-executions | Retrieve multiple WorkflowExecutions
*PlatformApi* | [**get_many_base_workflow_execution_spec_controller_workflow_execution_spec**](docs/PlatformApi.md#get_many_base_workflow_execution_spec_controller_workflow_execution_spec) | **GET** /workflow-execution-specs | Retrieve multiple WorkflowExecutionSpecs
*PlatformApi* | [**get_many_base_workflow_execution_status_controller_workflow_execution_status**](docs/PlatformApi.md#get_many_base_workflow_execution_status_controller_workflow_execution_status) | **GET** /workflow-execution-statuses | Retrieve multiple WorkflowExecutionStatuses
*PlatformApi* | [**get_many_base_workflow_template_controller_workflow_template**](docs/PlatformApi.md#get_many_base_workflow_template_controller_workflow_template) | **GET** /workflow-templates | Retrieve multiple WorkflowTemplates
*PlatformApi* | [**get_one_base_cohort_controller_cohort**](docs/PlatformApi.md#get_one_base_cohort_controller_cohort) | **GET** /cohorts/{id} | Retrieve a single Cohort
*PlatformApi* | [**get_one_base_data_query_controller_data_query**](docs/PlatformApi.md#get_one_base_data_query_controller_data_query) | **GET** /data-queries/{id} | Retrieve a single DataQuery
*PlatformApi* | [**get_one_base_data_store_controller_data_store**](docs/PlatformApi.md#get_one_base_data_store_controller_data_store) | **GET** /data-stores/{id} | Retrieve a single DataStore
*PlatformApi* | [**get_one_base_data_table_controller_data_table**](docs/PlatformApi.md#get_one_base_data_table_controller_data_table) | **GET** /data-tables/{id} | Retrieve a single DataTable
*PlatformApi* | [**get_one_base_database_controller_database**](docs/PlatformApi.md#get_one_base_database_controller_database) | **GET** /databases/{id} | Retrieve a single Database
*PlatformApi* | [**get_one_base_dataset_column_controller_dataset_column**](docs/PlatformApi.md#get_one_base_dataset_column_controller_dataset_column) | **GET** /dataset-columns/{id} | Retrieve a single DatasetColumn
*PlatformApi* | [**get_one_base_dataset_controller_dataset**](docs/PlatformApi.md#get_one_base_dataset_controller_dataset) | **GET** /datasets/{id} | Retrieve a single Dataset
*PlatformApi* | [**get_one_base_feature_controller_feature**](docs/PlatformApi.md#get_one_base_feature_controller_feature) | **GET** /features/{id} | Retrieve a single Feature
*PlatformApi* | [**get_one_base_feature_service_controller_feature_service**](docs/PlatformApi.md#get_one_base_feature_service_controller_feature_service) | **GET** /feature-services/{id} | Retrieve a single FeatureService
*PlatformApi* | [**get_one_base_feature_store_controller_feature_store**](docs/PlatformApi.md#get_one_base_feature_store_controller_feature_store) | **GET** /feature-stores/{id} | Retrieve a single FeatureStore
*PlatformApi* | [**get_one_base_feature_table_controller_feature_table**](docs/PlatformApi.md#get_one_base_feature_table_controller_feature_table) | **GET** /feature-tables/{id} | Retrieve a single FeatureTable
*PlatformApi* | [**get_one_base_feature_view_controller_feature_view**](docs/PlatformApi.md#get_one_base_feature_view_controller_feature_view) | **GET** /feature-views/{id} | Retrieve a single FeatureView
*PlatformApi* | [**get_one_base_model_controller_model**](docs/PlatformApi.md#get_one_base_model_controller_model) | **GET** /models/{id} | Retrieve a single Model
*PlatformApi* | [**get_one_base_model_job_controller_model_job**](docs/PlatformApi.md#get_one_base_model_job_controller_model_job) | **GET** /model-jobs/{id} | Retrieve a single ModelJob
*PlatformApi* | [**get_one_base_model_job_output_controller_model_job_output**](docs/PlatformApi.md#get_one_base_model_job_output_controller_model_job_output) | **GET** /model-job-outputs/{id} | Retrieve a single ModelJobOutput
*PlatformApi* | [**get_one_base_model_job_status_controller_model_job_status**](docs/PlatformApi.md#get_one_base_model_job_status_controller_model_job_status) | **GET** /model-job-statuses/{id} | Retrieve a single ModelJobStatus
*PlatformApi* | [**get_one_base_model_population_controller_model_population**](docs/PlatformApi.md#get_one_base_model_population_controller_model_population) | **GET** /model-populations/{id} | Retrieve a single ModelPopulation
*PlatformApi* | [**get_one_base_organization_setting_controller_organization_setting**](docs/PlatformApi.md#get_one_base_organization_setting_controller_organization_setting) | **GET** /organization-settings/{id} | Retrieve a single OrganizationSetting
*PlatformApi* | [**get_one_base_organizations_controller_organization**](docs/PlatformApi.md#get_one_base_organizations_controller_organization) | **GET** /organizations/{id} | Retrieve a single Organization
*PlatformApi* | [**get_one_base_population_store_controller_population_store**](docs/PlatformApi.md#get_one_base_population_store_controller_population_store) | **GET** /population-stores/{id} | Retrieve a single PopulationStore
*PlatformApi* | [**get_one_base_project_controller_project**](docs/PlatformApi.md#get_one_base_project_controller_project) | **GET** /projects/{id} | Retrieve a single Project
*PlatformApi* | [**get_one_base_project_member_controller_project_member**](docs/PlatformApi.md#get_one_base_project_member_controller_project_member) | **GET** /project-members/{id} | Retrieve a single ProjectMember
*PlatformApi* | [**get_one_base_scheduler_controller_scheduler**](docs/PlatformApi.md#get_one_base_scheduler_controller_scheduler) | **GET** /schedulers/{id} | Retrieve a single Scheduler
*PlatformApi* | [**get_one_base_task_controller_task**](docs/PlatformApi.md#get_one_base_task_controller_task) | **GET** /tasks/{id} | Retrieve a single Task
*PlatformApi* | [**get_one_base_task_execution_controller_task_execution**](docs/PlatformApi.md#get_one_base_task_execution_controller_task_execution) | **GET** /task-executions/{id} | Retrieve a single TaskExecution
*PlatformApi* | [**get_one_base_task_execution_status_controller_task_execution_status**](docs/PlatformApi.md#get_one_base_task_execution_status_controller_task_execution_status) | **GET** /task-execution-statuses/{id} | Retrieve a single TaskExecutionStatus
*PlatformApi* | [**get_one_base_tecton_feature_controller_tecton_feature**](docs/PlatformApi.md#get_one_base_tecton_feature_controller_tecton_feature) | **GET** /tecton-features/{id} | Retrieve a single TectonFeature
*PlatformApi* | [**get_one_base_user_audit_trail_controller_user_audit_trail**](docs/PlatformApi.md#get_one_base_user_audit_trail_controller_user_audit_trail) | **GET** /user-audit-trail/{id} | Retrieve a single UserAuditTrail
*PlatformApi* | [**get_one_base_user_favorite_controller_user_favorite**](docs/PlatformApi.md#get_one_base_user_favorite_controller_user_favorite) | **GET** /user-favorites/{id} | Retrieve a single UserFavorite
*PlatformApi* | [**get_one_base_workflow_controller_workflow**](docs/PlatformApi.md#get_one_base_workflow_controller_workflow) | **GET** /workflows/{id} | Retrieve a single Workflow
*PlatformApi* | [**get_one_base_workflow_execution_controller_workflow_execution**](docs/PlatformApi.md#get_one_base_workflow_execution_controller_workflow_execution) | **GET** /workflow-executions/{id} | Retrieve a single WorkflowExecution
*PlatformApi* | [**get_one_base_workflow_execution_spec_controller_workflow_execution_spec**](docs/PlatformApi.md#get_one_base_workflow_execution_spec_controller_workflow_execution_spec) | **GET** /workflow-execution-specs/{id} | Retrieve a single WorkflowExecutionSpec
*PlatformApi* | [**get_one_base_workflow_execution_status_controller_workflow_execution_status**](docs/PlatformApi.md#get_one_base_workflow_execution_status_controller_workflow_execution_status) | **GET** /workflow-execution-statuses/{id} | Retrieve a single WorkflowExecutionStatus
*PlatformApi* | [**get_one_base_workflow_template_controller_workflow_template**](docs/PlatformApi.md#get_one_base_workflow_template_controller_workflow_template) | **GET** /workflow-templates/{id} | Retrieve a single WorkflowTemplate
*PlatformApi* | [**model_controller_clone_model**](docs/PlatformApi.md#model_controller_clone_model) | **POST** /models/{id}/clone | Clone existing model
*PlatformApi* | [**model_controller_get_many_and_join_metadata**](docs/PlatformApi.md#model_controller_get_many_and_join_metadata) | **GET** /models/detailed | Retrieve model and metadata
*PlatformApi* | [**model_controller_get_recent_models**](docs/PlatformApi.md#model_controller_get_recent_models) | **GET** /models/recent | Retrieve recent models
*PlatformApi* | [**model_job_controller_generate_odhq**](docs/PlatformApi.md#model_job_controller_generate_odhq) | **GET** /model-jobs/{id}/generate-odhq | Execute Outcome Distribution Histogram Query
*PlatformApi* | [**model_job_controller_get_predictions_data**](docs/PlatformApi.md#model_job_controller_get_predictions_data) | **GET** /model-jobs/{id}/predictions | Retrieve model job predictions
*PlatformApi* | [**model_job_controller_start**](docs/PlatformApi.md#model_job_controller_start) | **GET** /model-jobs/{id}/start | Start model job
*PlatformApi* | [**model_job_controller_stop**](docs/PlatformApi.md#model_job_controller_stop) | **GET** /model-jobs/{id}/stop | Stop Model job
*PlatformApi* | [**model_job_status_controller_bulk_update_project_id**](docs/PlatformApi.md#model_job_status_controller_bulk_update_project_id) | **POST** /model-job-statuses/bulk-update-project-id | 
*PlatformApi* | [**model_population_controller_queue_query**](docs/PlatformApi.md#model_population_controller_queue_query) | **POST** /model-populations/{id}/queue-query/{type} | Queue model population query
*PlatformApi* | [**organization_setting_controller_get_unscoped_organization_settings**](docs/PlatformApi.md#organization_setting_controller_get_unscoped_organization_settings) | **GET** /organization-settings/unscoped | Retrieve all organization settings
*PlatformApi* | [**organization_setting_controller_get_versions**](docs/PlatformApi.md#organization_setting_controller_get_versions) | **GET** /organization-settings/versions | Retrieve container versions
*PlatformApi* | [**organization_setting_controller_get_versions_0**](docs/PlatformApi.md#organization_setting_controller_get_versions_0) | **GET** /organization-settings/versions | Retrieve container versions
*PlatformApi* | [**project_controller_get_all_project_children**](docs/PlatformApi.md#project_controller_get_all_project_children) | **GET** /projects/{id}/children | Retrieve project and child projects
*PlatformApi* | [**project_controller_get_all_project_parents**](docs/PlatformApi.md#project_controller_get_all_project_parents) | **GET** /projects/{id}/parents | Retrieve project and parent projects
*PlatformApi* | [**project_controller_get_recent_projects**](docs/PlatformApi.md#project_controller_get_recent_projects) | **GET** /projects/recent | Retrieve recent projects for user
*PlatformApi* | [**replace_one_base_cohort_controller_cohort**](docs/PlatformApi.md#replace_one_base_cohort_controller_cohort) | **PUT** /cohorts/{id} | Replace a single Cohort
*PlatformApi* | [**replace_one_base_data_query_controller_data_query**](docs/PlatformApi.md#replace_one_base_data_query_controller_data_query) | **PUT** /data-queries/{id} | Replace a single DataQuery
*PlatformApi* | [**replace_one_base_data_store_controller_data_store**](docs/PlatformApi.md#replace_one_base_data_store_controller_data_store) | **PUT** /data-stores/{id} | Replace a single DataStore
*PlatformApi* | [**replace_one_base_dataset_column_controller_dataset_column**](docs/PlatformApi.md#replace_one_base_dataset_column_controller_dataset_column) | **PUT** /dataset-columns/{id} | Replace a single DatasetColumn
*PlatformApi* | [**replace_one_base_dataset_controller_dataset**](docs/PlatformApi.md#replace_one_base_dataset_controller_dataset) | **PUT** /datasets/{id} | Replace a single Dataset
*PlatformApi* | [**replace_one_base_feature_controller_feature**](docs/PlatformApi.md#replace_one_base_feature_controller_feature) | **PUT** /features/{id} | Replace a single Feature
*PlatformApi* | [**replace_one_base_feature_service_controller_feature_service**](docs/PlatformApi.md#replace_one_base_feature_service_controller_feature_service) | **PUT** /feature-services/{id} | Replace a single FeatureService
*PlatformApi* | [**replace_one_base_feature_store_controller_feature_store**](docs/PlatformApi.md#replace_one_base_feature_store_controller_feature_store) | **PUT** /feature-stores/{id} | Replace a single FeatureStore
*PlatformApi* | [**replace_one_base_feature_table_controller_feature_table**](docs/PlatformApi.md#replace_one_base_feature_table_controller_feature_table) | **PUT** /feature-tables/{id} | Replace a single FeatureTable
*PlatformApi* | [**replace_one_base_feature_view_controller_feature_view**](docs/PlatformApi.md#replace_one_base_feature_view_controller_feature_view) | **PUT** /feature-views/{id} | Replace a single FeatureView
*PlatformApi* | [**replace_one_base_model_controller_model**](docs/PlatformApi.md#replace_one_base_model_controller_model) | **PUT** /models/{id} | Replace a single Model
*PlatformApi* | [**replace_one_base_model_job_controller_model_job**](docs/PlatformApi.md#replace_one_base_model_job_controller_model_job) | **PUT** /model-jobs/{id} | Replace a single ModelJob
*PlatformApi* | [**replace_one_base_model_job_output_controller_model_job_output**](docs/PlatformApi.md#replace_one_base_model_job_output_controller_model_job_output) | **PUT** /model-job-outputs/{id} | Replace a single ModelJobOutput
*PlatformApi* | [**replace_one_base_model_population_controller_model_population**](docs/PlatformApi.md#replace_one_base_model_population_controller_model_population) | **PUT** /model-populations/{id} | Replace a single ModelPopulation
*PlatformApi* | [**replace_one_base_organization_setting_controller_organization_setting**](docs/PlatformApi.md#replace_one_base_organization_setting_controller_organization_setting) | **PUT** /organization-settings/{id} | Replace a single OrganizationSetting
*PlatformApi* | [**replace_one_base_organizations_controller_organization**](docs/PlatformApi.md#replace_one_base_organizations_controller_organization) | **PUT** /organizations/{id} | Replace a single Organization
*PlatformApi* | [**replace_one_base_population_store_controller_population_store**](docs/PlatformApi.md#replace_one_base_population_store_controller_population_store) | **PUT** /population-stores/{id} | Replace a single PopulationStore
*PlatformApi* | [**replace_one_base_project_controller_project**](docs/PlatformApi.md#replace_one_base_project_controller_project) | **PUT** /projects/{id} | Replace a single Project
*PlatformApi* | [**replace_one_base_project_member_controller_project_member**](docs/PlatformApi.md#replace_one_base_project_member_controller_project_member) | **PUT** /project-members/{id} | Replace a single ProjectMember
*PlatformApi* | [**replace_one_base_scheduler_controller_scheduler**](docs/PlatformApi.md#replace_one_base_scheduler_controller_scheduler) | **PUT** /schedulers/{id} | Replace a single Scheduler
*PlatformApi* | [**replace_one_base_task_controller_task**](docs/PlatformApi.md#replace_one_base_task_controller_task) | **PUT** /tasks/{id} | Replace a single Task
*PlatformApi* | [**replace_one_base_task_execution_controller_task_execution**](docs/PlatformApi.md#replace_one_base_task_execution_controller_task_execution) | **PUT** /task-executions/{id} | Replace a single TaskExecution
*PlatformApi* | [**replace_one_base_task_execution_status_controller_task_execution_status**](docs/PlatformApi.md#replace_one_base_task_execution_status_controller_task_execution_status) | **PUT** /task-execution-statuses/{id} | Replace a single TaskExecutionStatus
*PlatformApi* | [**replace_one_base_tecton_feature_controller_tecton_feature**](docs/PlatformApi.md#replace_one_base_tecton_feature_controller_tecton_feature) | **PUT** /tecton-features/{id} | Replace a single TectonFeature
*PlatformApi* | [**replace_one_base_user_favorite_controller_user_favorite**](docs/PlatformApi.md#replace_one_base_user_favorite_controller_user_favorite) | **PUT** /user-favorites/{id} | Replace a single UserFavorite
*PlatformApi* | [**replace_one_base_workflow_controller_workflow**](docs/PlatformApi.md#replace_one_base_workflow_controller_workflow) | **PUT** /workflows/{id} | Replace a single Workflow
*PlatformApi* | [**replace_one_base_workflow_execution_controller_workflow_execution**](docs/PlatformApi.md#replace_one_base_workflow_execution_controller_workflow_execution) | **PUT** /workflow-executions/{id} | Replace a single WorkflowExecution
*PlatformApi* | [**replace_one_base_workflow_execution_spec_controller_workflow_execution_spec**](docs/PlatformApi.md#replace_one_base_workflow_execution_spec_controller_workflow_execution_spec) | **PUT** /workflow-execution-specs/{id} | Replace a single WorkflowExecutionSpec
*PlatformApi* | [**replace_one_base_workflow_template_controller_workflow_template**](docs/PlatformApi.md#replace_one_base_workflow_template_controller_workflow_template) | **PUT** /workflow-templates/{id} | Replace a single WorkflowTemplate
*PlatformApi* | [**task_controller_create_task_from_databricks_job**](docs/PlatformApi.md#task_controller_create_task_from_databricks_job) | **POST** /tasks/create-from-databricks-job/ | Create task from Databricks job
*PlatformApi* | [**task_controller_get_awsecr_repos**](docs/PlatformApi.md#task_controller_get_awsecr_repos) | **GET** /tasks/ecr-repos | List ECR repos
*PlatformApi* | [**task_controller_list_databricks_jobs**](docs/PlatformApi.md#task_controller_list_databricks_jobs) | **GET** /tasks/databricks-jobs | List Databricks jobs
*PlatformApi* | [**update_one_base_cohort_controller_cohort**](docs/PlatformApi.md#update_one_base_cohort_controller_cohort) | **PATCH** /cohorts/{id} | Update a single Cohort
*PlatformApi* | [**update_one_base_data_query_controller_data_query**](docs/PlatformApi.md#update_one_base_data_query_controller_data_query) | **PATCH** /data-queries/{id} | Update a single DataQuery
*PlatformApi* | [**update_one_base_data_store_controller_data_store**](docs/PlatformApi.md#update_one_base_data_store_controller_data_store) | **PATCH** /data-stores/{id} | Update a single DataStore
*PlatformApi* | [**update_one_base_dataset_column_controller_dataset_column**](docs/PlatformApi.md#update_one_base_dataset_column_controller_dataset_column) | **PATCH** /dataset-columns/{id} | Update a single DatasetColumn
*PlatformApi* | [**update_one_base_dataset_controller_dataset**](docs/PlatformApi.md#update_one_base_dataset_controller_dataset) | **PATCH** /datasets/{id} | Update a single Dataset
*PlatformApi* | [**update_one_base_feature_controller_feature**](docs/PlatformApi.md#update_one_base_feature_controller_feature) | **PATCH** /features/{id} | Update a single Feature
*PlatformApi* | [**update_one_base_feature_service_controller_feature_service**](docs/PlatformApi.md#update_one_base_feature_service_controller_feature_service) | **PATCH** /feature-services/{id} | Update a single FeatureService
*PlatformApi* | [**update_one_base_feature_store_controller_feature_store**](docs/PlatformApi.md#update_one_base_feature_store_controller_feature_store) | **PATCH** /feature-stores/{id} | Update a single FeatureStore
*PlatformApi* | [**update_one_base_feature_table_controller_feature_table**](docs/PlatformApi.md#update_one_base_feature_table_controller_feature_table) | **PATCH** /feature-tables/{id} | Update a single FeatureTable
*PlatformApi* | [**update_one_base_feature_view_controller_feature_view**](docs/PlatformApi.md#update_one_base_feature_view_controller_feature_view) | **PATCH** /feature-views/{id} | Update a single FeatureView
*PlatformApi* | [**update_one_base_model_controller_model**](docs/PlatformApi.md#update_one_base_model_controller_model) | **PATCH** /models/{id} | Update a single Model
*PlatformApi* | [**update_one_base_model_job_controller_model_job**](docs/PlatformApi.md#update_one_base_model_job_controller_model_job) | **PATCH** /model-jobs/{id} | Update a single ModelJob
*PlatformApi* | [**update_one_base_model_job_output_controller_model_job_output**](docs/PlatformApi.md#update_one_base_model_job_output_controller_model_job_output) | **PATCH** /model-job-outputs/{id} | Update a single ModelJobOutput
*PlatformApi* | [**update_one_base_model_population_controller_model_population**](docs/PlatformApi.md#update_one_base_model_population_controller_model_population) | **PATCH** /model-populations/{id} | Update a single ModelPopulation
*PlatformApi* | [**update_one_base_organization_setting_controller_organization_setting**](docs/PlatformApi.md#update_one_base_organization_setting_controller_organization_setting) | **PATCH** /organization-settings/{id} | Update a single OrganizationSetting
*PlatformApi* | [**update_one_base_organizations_controller_organization**](docs/PlatformApi.md#update_one_base_organizations_controller_organization) | **PATCH** /organizations/{id} | Update a single Organization
*PlatformApi* | [**update_one_base_population_store_controller_population_store**](docs/PlatformApi.md#update_one_base_population_store_controller_population_store) | **PATCH** /population-stores/{id} | Update a single PopulationStore
*PlatformApi* | [**update_one_base_project_controller_project**](docs/PlatformApi.md#update_one_base_project_controller_project) | **PATCH** /projects/{id} | Update a single Project
*PlatformApi* | [**update_one_base_project_member_controller_project_member**](docs/PlatformApi.md#update_one_base_project_member_controller_project_member) | **PATCH** /project-members/{id} | Update a single ProjectMember
*PlatformApi* | [**update_one_base_scheduler_controller_scheduler**](docs/PlatformApi.md#update_one_base_scheduler_controller_scheduler) | **PATCH** /schedulers/{id} | Update a single Scheduler
*PlatformApi* | [**update_one_base_task_controller_task**](docs/PlatformApi.md#update_one_base_task_controller_task) | **PATCH** /tasks/{id} | Update a single Task
*PlatformApi* | [**update_one_base_task_execution_controller_task_execution**](docs/PlatformApi.md#update_one_base_task_execution_controller_task_execution) | **PATCH** /task-executions/{id} | Update a single TaskExecution
*PlatformApi* | [**update_one_base_task_execution_status_controller_task_execution_status**](docs/PlatformApi.md#update_one_base_task_execution_status_controller_task_execution_status) | **PATCH** /task-execution-statuses/{id} | Update a single TaskExecutionStatus
*PlatformApi* | [**update_one_base_tecton_feature_controller_tecton_feature**](docs/PlatformApi.md#update_one_base_tecton_feature_controller_tecton_feature) | **PATCH** /tecton-features/{id} | Update a single TectonFeature
*PlatformApi* | [**update_one_base_user_favorite_controller_user_favorite**](docs/PlatformApi.md#update_one_base_user_favorite_controller_user_favorite) | **PATCH** /user-favorites/{id} | Update a single UserFavorite
*PlatformApi* | [**update_one_base_workflow_controller_workflow**](docs/PlatformApi.md#update_one_base_workflow_controller_workflow) | **PATCH** /workflows/{id} | Update a single Workflow
*PlatformApi* | [**update_one_base_workflow_execution_controller_workflow_execution**](docs/PlatformApi.md#update_one_base_workflow_execution_controller_workflow_execution) | **PATCH** /workflow-executions/{id} | Update a single WorkflowExecution
*PlatformApi* | [**update_one_base_workflow_execution_spec_controller_workflow_execution_spec**](docs/PlatformApi.md#update_one_base_workflow_execution_spec_controller_workflow_execution_spec) | **PATCH** /workflow-execution-specs/{id} | Update a single WorkflowExecutionSpec
*PlatformApi* | [**update_one_base_workflow_template_controller_workflow_template**](docs/PlatformApi.md#update_one_base_workflow_template_controller_workflow_template) | **PATCH** /workflow-templates/{id} | Update a single WorkflowTemplate
*PlatformApi* | [**user_management_controller_assign_user_roles**](docs/PlatformApi.md#user_management_controller_assign_user_roles) | **PUT** /user-management/{id}/assign-roles | Assign user roles
*PlatformApi* | [**user_management_controller_cancel_user_invite**](docs/PlatformApi.md#user_management_controller_cancel_user_invite) | **POST** /user-management/invite/cancel | Cancel user invitation
*PlatformApi* | [**user_management_controller_get_my_user**](docs/PlatformApi.md#user_management_controller_get_my_user) | **GET** /user-management/my-user | Retrieve your user
*PlatformApi* | [**user_management_controller_get_my_user_api_key**](docs/PlatformApi.md#user_management_controller_get_my_user_api_key) | **GET** /user-management/my-api-key | Retrieve your api-key
*PlatformApi* | [**user_management_controller_get_my_user_organizations**](docs/PlatformApi.md#user_management_controller_get_my_user_organizations) | **GET** /user-management/my-organizations | Retrieve user organizations
*PlatformApi* | [**user_management_controller_get_roles**](docs/PlatformApi.md#user_management_controller_get_roles) | **GET** /user-management/roles | Retrieves user roles
*PlatformApi* | [**user_management_controller_get_user**](docs/PlatformApi.md#user_management_controller_get_user) | **GET** /user-management/{id} | Retrieve one user
*PlatformApi* | [**user_management_controller_get_users**](docs/PlatformApi.md#user_management_controller_get_users) | **GET** /user-management | Retrieve many users
*PlatformApi* | [**user_management_controller_invite_user**](docs/PlatformApi.md#user_management_controller_invite_user) | **POST** /user-management/invite | Invite a User
*PlatformApi* | [**user_management_controller_refresh_api_key**](docs/PlatformApi.md#user_management_controller_refresh_api_key) | **GET** /user-management/{id}/refresh-api-key | Refresh api key for userid
*PlatformApi* | [**user_management_controller_refresh_my_api_key**](docs/PlatformApi.md#user_management_controller_refresh_my_api_key) | **GET** /user-management/refresh-my-api-key | Refresh user api key
*PlatformApi* | [**user_management_controller_remove_user**](docs/PlatformApi.md#user_management_controller_remove_user) | **DELETE** /user-management/{id} | Delete one User
*PlatformApi* | [**user_management_controller_remove_user_roles**](docs/PlatformApi.md#user_management_controller_remove_user_roles) | **PUT** /user-management/{id}/remove-roles | Remove user roles
*PlatformApi* | [**user_management_controller_request_password_reset**](docs/PlatformApi.md#user_management_controller_request_password_reset) | **GET** /user-management/{id}/request-password-reset | Request user password reset
*PlatformApi* | [**user_management_controller_resend_user_invite**](docs/PlatformApi.md#user_management_controller_resend_user_invite) | **POST** /user-management/invite/resend | Resend user invitation
*PlatformApi* | [**user_management_controller_update_my_user**](docs/PlatformApi.md#user_management_controller_update_my_user) | **PATCH** /user-management/my-user | Update my User
*PlatformApi* | [**user_management_controller_update_user**](docs/PlatformApi.md#user_management_controller_update_user) | **PATCH** /user-management/{id} | Update one User
*PlatformApi* | [**user_management_controller_update_user_metadata**](docs/PlatformApi.md#user_management_controller_update_user_metadata) | **PUT** /user-management/{id}/metadata | Update one user metadata
*PlatformApi* | [**workflow_controller_execute**](docs/PlatformApi.md#workflow_controller_execute) | **GET** /workflows/{id}/execute | Execute Workflow
*PlatformApi* | [**workflow_controller_execute_post**](docs/PlatformApi.md#workflow_controller_execute_post) | **POST** /workflows/{id}/execute | Execute Workflow
*PlatformApi* | [**workflow_execution_controller_get_full_graph**](docs/PlatformApi.md#workflow_execution_controller_get_full_graph) | **GET** /workflow-executions/{id}/expanded-tree | 
*PlatformApi* | [**workflow_execution_spec_controller_get_full_graph**](docs/PlatformApi.md#workflow_execution_spec_controller_get_full_graph) | **GET** /workflow-execution-specs/{id}/expanded-tree | 
*PopulationStoresApi* | [**create_many_base_population_store_controller_population_store**](docs/PopulationStoresApi.md#create_many_base_population_store_controller_population_store) | **POST** /population-stores/bulk | Create multiple PopulationStores
*PopulationStoresApi* | [**create_one_base_population_store_controller_population_store**](docs/PopulationStoresApi.md#create_one_base_population_store_controller_population_store) | **POST** /population-stores | Create a single PopulationStore
*PopulationStoresApi* | [**delete_one_base_population_store_controller_population_store**](docs/PopulationStoresApi.md#delete_one_base_population_store_controller_population_store) | **DELETE** /population-stores/{id} | Delete a single PopulationStore
*PopulationStoresApi* | [**get_many_base_population_store_controller_population_store**](docs/PopulationStoresApi.md#get_many_base_population_store_controller_population_store) | **GET** /population-stores | Retrieve multiple PopulationStores
*PopulationStoresApi* | [**get_one_base_population_store_controller_population_store**](docs/PopulationStoresApi.md#get_one_base_population_store_controller_population_store) | **GET** /population-stores/{id} | Retrieve a single PopulationStore
*PopulationStoresApi* | [**replace_one_base_population_store_controller_population_store**](docs/PopulationStoresApi.md#replace_one_base_population_store_controller_population_store) | **PUT** /population-stores/{id} | Replace a single PopulationStore
*PopulationStoresApi* | [**update_one_base_population_store_controller_population_store**](docs/PopulationStoresApi.md#update_one_base_population_store_controller_population_store) | **PATCH** /population-stores/{id} | Update a single PopulationStore
*ProjectMembersApi* | [**create_many_base_project_member_controller_project_member**](docs/ProjectMembersApi.md#create_many_base_project_member_controller_project_member) | **POST** /project-members/bulk | Create multiple ProjectMembers
*ProjectMembersApi* | [**create_one_base_project_member_controller_project_member**](docs/ProjectMembersApi.md#create_one_base_project_member_controller_project_member) | **POST** /project-members | Create a single ProjectMember
*ProjectMembersApi* | [**delete_one_base_project_member_controller_project_member**](docs/ProjectMembersApi.md#delete_one_base_project_member_controller_project_member) | **DELETE** /project-members/{id} | Delete a single ProjectMember
*ProjectMembersApi* | [**get_many_base_project_member_controller_project_member**](docs/ProjectMembersApi.md#get_many_base_project_member_controller_project_member) | **GET** /project-members | Retrieve multiple ProjectMembers
*ProjectMembersApi* | [**get_one_base_project_member_controller_project_member**](docs/ProjectMembersApi.md#get_one_base_project_member_controller_project_member) | **GET** /project-members/{id} | Retrieve a single ProjectMember
*ProjectMembersApi* | [**replace_one_base_project_member_controller_project_member**](docs/ProjectMembersApi.md#replace_one_base_project_member_controller_project_member) | **PUT** /project-members/{id} | Replace a single ProjectMember
*ProjectMembersApi* | [**update_one_base_project_member_controller_project_member**](docs/ProjectMembersApi.md#update_one_base_project_member_controller_project_member) | **PATCH** /project-members/{id} | Update a single ProjectMember
*ProjectsApi* | [**create_many_base_project_controller_project**](docs/ProjectsApi.md#create_many_base_project_controller_project) | **POST** /projects/bulk | Create multiple Projects
*ProjectsApi* | [**create_one_base_project_controller_project**](docs/ProjectsApi.md#create_one_base_project_controller_project) | **POST** /projects | Create a single Project
*ProjectsApi* | [**delete_one_base_project_controller_project**](docs/ProjectsApi.md#delete_one_base_project_controller_project) | **DELETE** /projects/{id} | Delete a single Project
*ProjectsApi* | [**get_many_base_project_controller_project**](docs/ProjectsApi.md#get_many_base_project_controller_project) | **GET** /projects | Retrieve multiple Projects
*ProjectsApi* | [**get_one_base_project_controller_project**](docs/ProjectsApi.md#get_one_base_project_controller_project) | **GET** /projects/{id} | Retrieve a single Project
*ProjectsApi* | [**project_controller_get_all_project_children**](docs/ProjectsApi.md#project_controller_get_all_project_children) | **GET** /projects/{id}/children | Retrieve project and child projects
*ProjectsApi* | [**project_controller_get_all_project_parents**](docs/ProjectsApi.md#project_controller_get_all_project_parents) | **GET** /projects/{id}/parents | Retrieve project and parent projects
*ProjectsApi* | [**project_controller_get_recent_projects**](docs/ProjectsApi.md#project_controller_get_recent_projects) | **GET** /projects/recent | Retrieve recent projects for user
*ProjectsApi* | [**replace_one_base_project_controller_project**](docs/ProjectsApi.md#replace_one_base_project_controller_project) | **PUT** /projects/{id} | Replace a single Project
*ProjectsApi* | [**update_one_base_project_controller_project**](docs/ProjectsApi.md#update_one_base_project_controller_project) | **PATCH** /projects/{id} | Update a single Project
*SchedulerApi* | [**create_many_base_scheduler_controller_scheduler**](docs/SchedulerApi.md#create_many_base_scheduler_controller_scheduler) | **POST** /schedulers/bulk | Create multiple Schedulers
*SchedulerApi* | [**create_one_base_scheduler_controller_scheduler**](docs/SchedulerApi.md#create_one_base_scheduler_controller_scheduler) | **POST** /schedulers | Create a single Scheduler
*SchedulerApi* | [**delete_one_base_scheduler_controller_scheduler**](docs/SchedulerApi.md#delete_one_base_scheduler_controller_scheduler) | **DELETE** /schedulers/{id} | Delete a single Scheduler
*SchedulerApi* | [**get_many_base_scheduler_controller_scheduler**](docs/SchedulerApi.md#get_many_base_scheduler_controller_scheduler) | **GET** /schedulers | Retrieve multiple Schedulers
*SchedulerApi* | [**get_one_base_scheduler_controller_scheduler**](docs/SchedulerApi.md#get_one_base_scheduler_controller_scheduler) | **GET** /schedulers/{id} | Retrieve a single Scheduler
*SchedulerApi* | [**replace_one_base_scheduler_controller_scheduler**](docs/SchedulerApi.md#replace_one_base_scheduler_controller_scheduler) | **PUT** /schedulers/{id} | Replace a single Scheduler
*SchedulerApi* | [**update_one_base_scheduler_controller_scheduler**](docs/SchedulerApi.md#update_one_base_scheduler_controller_scheduler) | **PATCH** /schedulers/{id} | Update a single Scheduler
*TasksApi* | [**create_many_base_task_controller_task**](docs/TasksApi.md#create_many_base_task_controller_task) | **POST** /tasks/bulk | Create multiple Tasks
*TasksApi* | [**create_one_base_task_controller_task**](docs/TasksApi.md#create_one_base_task_controller_task) | **POST** /tasks | Create a single Task
*TasksApi* | [**delete_one_base_task_controller_task**](docs/TasksApi.md#delete_one_base_task_controller_task) | **DELETE** /tasks/{id} | Delete a single Task
*TasksApi* | [**get_many_base_task_controller_task**](docs/TasksApi.md#get_many_base_task_controller_task) | **GET** /tasks | Retrieve multiple Tasks
*TasksApi* | [**get_one_base_task_controller_task**](docs/TasksApi.md#get_one_base_task_controller_task) | **GET** /tasks/{id} | Retrieve a single Task
*TasksApi* | [**replace_one_base_task_controller_task**](docs/TasksApi.md#replace_one_base_task_controller_task) | **PUT** /tasks/{id} | Replace a single Task
*TasksApi* | [**task_controller_create_task_from_databricks_job**](docs/TasksApi.md#task_controller_create_task_from_databricks_job) | **POST** /tasks/create-from-databricks-job/ | Create task from Databricks job
*TasksApi* | [**task_controller_get_awsecr_repos**](docs/TasksApi.md#task_controller_get_awsecr_repos) | **GET** /tasks/ecr-repos | List ECR repos
*TasksApi* | [**task_controller_list_databricks_jobs**](docs/TasksApi.md#task_controller_list_databricks_jobs) | **GET** /tasks/databricks-jobs | List Databricks jobs
*TasksApi* | [**update_one_base_task_controller_task**](docs/TasksApi.md#update_one_base_task_controller_task) | **PATCH** /tasks/{id} | Update a single Task
*TectonFeaturesApi* | [**create_many_base_tecton_feature_controller_tecton_feature**](docs/TectonFeaturesApi.md#create_many_base_tecton_feature_controller_tecton_feature) | **POST** /tecton-features/bulk | Create multiple TectonFeatures
*TectonFeaturesApi* | [**create_one_base_tecton_feature_controller_tecton_feature**](docs/TectonFeaturesApi.md#create_one_base_tecton_feature_controller_tecton_feature) | **POST** /tecton-features | Create a single TectonFeature
*TectonFeaturesApi* | [**delete_one_base_tecton_feature_controller_tecton_feature**](docs/TectonFeaturesApi.md#delete_one_base_tecton_feature_controller_tecton_feature) | **DELETE** /tecton-features/{id} | Delete a single TectonFeature
*TectonFeaturesApi* | [**get_many_base_tecton_feature_controller_tecton_feature**](docs/TectonFeaturesApi.md#get_many_base_tecton_feature_controller_tecton_feature) | **GET** /tecton-features | Retrieve multiple TectonFeatures
*TectonFeaturesApi* | [**get_one_base_tecton_feature_controller_tecton_feature**](docs/TectonFeaturesApi.md#get_one_base_tecton_feature_controller_tecton_feature) | **GET** /tecton-features/{id} | Retrieve a single TectonFeature
*TectonFeaturesApi* | [**replace_one_base_tecton_feature_controller_tecton_feature**](docs/TectonFeaturesApi.md#replace_one_base_tecton_feature_controller_tecton_feature) | **PUT** /tecton-features/{id} | Replace a single TectonFeature
*TectonFeaturesApi* | [**update_one_base_tecton_feature_controller_tecton_feature**](docs/TectonFeaturesApi.md#update_one_base_tecton_feature_controller_tecton_feature) | **PATCH** /tecton-features/{id} | Update a single TectonFeature
*UserAuditTrailApi* | [**get_many_base_user_audit_trail_controller_user_audit_trail**](docs/UserAuditTrailApi.md#get_many_base_user_audit_trail_controller_user_audit_trail) | **GET** /user-audit-trail | Retrieve multiple UserAuditTrails
*UserAuditTrailApi* | [**get_one_base_user_audit_trail_controller_user_audit_trail**](docs/UserAuditTrailApi.md#get_one_base_user_audit_trail_controller_user_audit_trail) | **GET** /user-audit-trail/{id} | Retrieve a single UserAuditTrail
*UserFavoritesApi* | [**create_many_base_user_favorite_controller_user_favorite**](docs/UserFavoritesApi.md#create_many_base_user_favorite_controller_user_favorite) | **POST** /user-favorites/bulk | Create multiple UserFavorites
*UserFavoritesApi* | [**create_one_base_user_favorite_controller_user_favorite**](docs/UserFavoritesApi.md#create_one_base_user_favorite_controller_user_favorite) | **POST** /user-favorites | Create a single UserFavorite
*UserFavoritesApi* | [**delete_one_base_user_favorite_controller_user_favorite**](docs/UserFavoritesApi.md#delete_one_base_user_favorite_controller_user_favorite) | **DELETE** /user-favorites/{id} | Delete a single UserFavorite
*UserFavoritesApi* | [**get_many_base_user_favorite_controller_user_favorite**](docs/UserFavoritesApi.md#get_many_base_user_favorite_controller_user_favorite) | **GET** /user-favorites | Retrieve multiple UserFavorites
*UserFavoritesApi* | [**get_one_base_user_favorite_controller_user_favorite**](docs/UserFavoritesApi.md#get_one_base_user_favorite_controller_user_favorite) | **GET** /user-favorites/{id} | Retrieve a single UserFavorite
*UserFavoritesApi* | [**replace_one_base_user_favorite_controller_user_favorite**](docs/UserFavoritesApi.md#replace_one_base_user_favorite_controller_user_favorite) | **PUT** /user-favorites/{id} | Replace a single UserFavorite
*UserFavoritesApi* | [**update_one_base_user_favorite_controller_user_favorite**](docs/UserFavoritesApi.md#update_one_base_user_favorite_controller_user_favorite) | **PATCH** /user-favorites/{id} | Update a single UserFavorite
*UserManagementApi* | [**user_management_controller_assign_user_roles**](docs/UserManagementApi.md#user_management_controller_assign_user_roles) | **PUT** /user-management/{id}/assign-roles | Assign user roles
*UserManagementApi* | [**user_management_controller_cancel_user_invite**](docs/UserManagementApi.md#user_management_controller_cancel_user_invite) | **POST** /user-management/invite/cancel | Cancel user invitation
*UserManagementApi* | [**user_management_controller_get_my_user**](docs/UserManagementApi.md#user_management_controller_get_my_user) | **GET** /user-management/my-user | Retrieve your user
*UserManagementApi* | [**user_management_controller_get_my_user_api_key**](docs/UserManagementApi.md#user_management_controller_get_my_user_api_key) | **GET** /user-management/my-api-key | Retrieve your api-key
*UserManagementApi* | [**user_management_controller_get_my_user_organizations**](docs/UserManagementApi.md#user_management_controller_get_my_user_organizations) | **GET** /user-management/my-organizations | Retrieve user organizations
*UserManagementApi* | [**user_management_controller_get_roles**](docs/UserManagementApi.md#user_management_controller_get_roles) | **GET** /user-management/roles | Retrieves user roles
*UserManagementApi* | [**user_management_controller_get_user**](docs/UserManagementApi.md#user_management_controller_get_user) | **GET** /user-management/{id} | Retrieve one user
*UserManagementApi* | [**user_management_controller_get_users**](docs/UserManagementApi.md#user_management_controller_get_users) | **GET** /user-management | Retrieve many users
*UserManagementApi* | [**user_management_controller_invite_user**](docs/UserManagementApi.md#user_management_controller_invite_user) | **POST** /user-management/invite | Invite a User
*UserManagementApi* | [**user_management_controller_refresh_api_key**](docs/UserManagementApi.md#user_management_controller_refresh_api_key) | **GET** /user-management/{id}/refresh-api-key | Refresh api key for userid
*UserManagementApi* | [**user_management_controller_refresh_my_api_key**](docs/UserManagementApi.md#user_management_controller_refresh_my_api_key) | **GET** /user-management/refresh-my-api-key | Refresh user api key
*UserManagementApi* | [**user_management_controller_remove_user**](docs/UserManagementApi.md#user_management_controller_remove_user) | **DELETE** /user-management/{id} | Delete one User
*UserManagementApi* | [**user_management_controller_remove_user_roles**](docs/UserManagementApi.md#user_management_controller_remove_user_roles) | **PUT** /user-management/{id}/remove-roles | Remove user roles
*UserManagementApi* | [**user_management_controller_request_password_reset**](docs/UserManagementApi.md#user_management_controller_request_password_reset) | **GET** /user-management/{id}/request-password-reset | Request user password reset
*UserManagementApi* | [**user_management_controller_resend_user_invite**](docs/UserManagementApi.md#user_management_controller_resend_user_invite) | **POST** /user-management/invite/resend | Resend user invitation
*UserManagementApi* | [**user_management_controller_update_my_user**](docs/UserManagementApi.md#user_management_controller_update_my_user) | **PATCH** /user-management/my-user | Update my User
*UserManagementApi* | [**user_management_controller_update_user**](docs/UserManagementApi.md#user_management_controller_update_user) | **PATCH** /user-management/{id} | Update one User
*UserManagementApi* | [**user_management_controller_update_user_metadata**](docs/UserManagementApi.md#user_management_controller_update_user_metadata) | **PUT** /user-management/{id}/metadata | Update one user metadata
*WorkflowsApi* | [**create_many_base_workflow_controller_workflow**](docs/WorkflowsApi.md#create_many_base_workflow_controller_workflow) | **POST** /workflows/bulk | Create multiple Workflows
*WorkflowsApi* | [**create_many_base_workflow_template_controller_workflow_template**](docs/WorkflowsApi.md#create_many_base_workflow_template_controller_workflow_template) | **POST** /workflow-templates/bulk | Create multiple WorkflowTemplates
*WorkflowsApi* | [**create_one_base_workflow_controller_workflow**](docs/WorkflowsApi.md#create_one_base_workflow_controller_workflow) | **POST** /workflows | Create a single Workflow
*WorkflowsApi* | [**create_one_base_workflow_template_controller_workflow_template**](docs/WorkflowsApi.md#create_one_base_workflow_template_controller_workflow_template) | **POST** /workflow-templates | Create a single WorkflowTemplate
*WorkflowsApi* | [**delete_one_base_workflow_controller_workflow**](docs/WorkflowsApi.md#delete_one_base_workflow_controller_workflow) | **DELETE** /workflows/{id} | Delete a single Workflow
*WorkflowsApi* | [**delete_one_base_workflow_template_controller_workflow_template**](docs/WorkflowsApi.md#delete_one_base_workflow_template_controller_workflow_template) | **DELETE** /workflow-templates/{id} | Delete a single WorkflowTemplate
*WorkflowsApi* | [**get_many_base_workflow_controller_workflow**](docs/WorkflowsApi.md#get_many_base_workflow_controller_workflow) | **GET** /workflows | Retrieve multiple Workflows
*WorkflowsApi* | [**get_many_base_workflow_template_controller_workflow_template**](docs/WorkflowsApi.md#get_many_base_workflow_template_controller_workflow_template) | **GET** /workflow-templates | Retrieve multiple WorkflowTemplates
*WorkflowsApi* | [**get_one_base_workflow_controller_workflow**](docs/WorkflowsApi.md#get_one_base_workflow_controller_workflow) | **GET** /workflows/{id} | Retrieve a single Workflow
*WorkflowsApi* | [**get_one_base_workflow_template_controller_workflow_template**](docs/WorkflowsApi.md#get_one_base_workflow_template_controller_workflow_template) | **GET** /workflow-templates/{id} | Retrieve a single WorkflowTemplate
*WorkflowsApi* | [**replace_one_base_workflow_controller_workflow**](docs/WorkflowsApi.md#replace_one_base_workflow_controller_workflow) | **PUT** /workflows/{id} | Replace a single Workflow
*WorkflowsApi* | [**replace_one_base_workflow_template_controller_workflow_template**](docs/WorkflowsApi.md#replace_one_base_workflow_template_controller_workflow_template) | **PUT** /workflow-templates/{id} | Replace a single WorkflowTemplate
*WorkflowsApi* | [**update_one_base_workflow_controller_workflow**](docs/WorkflowsApi.md#update_one_base_workflow_controller_workflow) | **PATCH** /workflows/{id} | Update a single Workflow
*WorkflowsApi* | [**update_one_base_workflow_template_controller_workflow_template**](docs/WorkflowsApi.md#update_one_base_workflow_template_controller_workflow_template) | **PATCH** /workflow-templates/{id} | Update a single WorkflowTemplate
*WorkflowsApi* | [**workflow_controller_execute**](docs/WorkflowsApi.md#workflow_controller_execute) | **GET** /workflows/{id}/execute | Execute Workflow
*WorkflowsApi* | [**workflow_controller_execute_post**](docs/WorkflowsApi.md#workflow_controller_execute_post) | **POST** /workflows/{id}/execute | Execute Workflow

## Documentation For Models

 - [AllOfDataTableDataset](docs/AllOfDataTableDataset.md)
 - [ArithmeticExpression](docs/ArithmeticExpression.md)
 - [Body](docs/Body.md)
 - [Body1](docs/Body1.md)
 - [Body2](docs/Body2.md)
 - [Body3](docs/Body3.md)
 - [Body4](docs/Body4.md)
 - [Body5](docs/Body5.md)
 - [BooleanExpression](docs/BooleanExpression.md)
 - [Cohort](docs/Cohort.md)
 - [CohortDefinition](docs/CohortDefinition.md)
 - [CohortFilter](docs/CohortFilter.md)
 - [CohortFilterCondition](docs/CohortFilterCondition.md)
 - [CohortJoinedCohortResponseDto](docs/CohortJoinedCohortResponseDto.md)
 - [CohortJoinedModelJobResponseDto](docs/CohortJoinedModelJobResponseDto.md)
 - [CohortResponseDto](docs/CohortResponseDto.md)
 - [CohortResults](docs/CohortResults.md)
 - [CohortWindow](docs/CohortWindow.md)
 - [Condition](docs/Condition.md)
 - [ContainerConfig](docs/ContainerConfig.md)
 - [CreateCohortDto](docs/CreateCohortDto.md)
 - [CreateDataQueryDto](docs/CreateDataQueryDto.md)
 - [CreateDataStoreDto](docs/CreateDataStoreDto.md)
 - [CreateDataTableDto](docs/CreateDataTableDto.md)
 - [CreateDatabaseDto](docs/CreateDatabaseDto.md)
 - [CreateDatasetColumnDto](docs/CreateDatasetColumnDto.md)
 - [CreateDatasetDto](docs/CreateDatasetDto.md)
 - [CreateFeatureDto](docs/CreateFeatureDto.md)
 - [CreateFeatureServiceDto](docs/CreateFeatureServiceDto.md)
 - [CreateFeatureStoreDto](docs/CreateFeatureStoreDto.md)
 - [CreateFeatureTableDto](docs/CreateFeatureTableDto.md)
 - [CreateFeatureViewDto](docs/CreateFeatureViewDto.md)
 - [CreateManyCohortDto](docs/CreateManyCohortDto.md)
 - [CreateManyDataQueryDto](docs/CreateManyDataQueryDto.md)
 - [CreateManyDataStoreDto](docs/CreateManyDataStoreDto.md)
 - [CreateManyDatasetColumnDto](docs/CreateManyDatasetColumnDto.md)
 - [CreateManyDatasetDto](docs/CreateManyDatasetDto.md)
 - [CreateManyFeatureDto](docs/CreateManyFeatureDto.md)
 - [CreateManyFeatureServiceDto](docs/CreateManyFeatureServiceDto.md)
 - [CreateManyFeatureStoreDto](docs/CreateManyFeatureStoreDto.md)
 - [CreateManyFeatureTableDto](docs/CreateManyFeatureTableDto.md)
 - [CreateManyFeatureViewDto](docs/CreateManyFeatureViewDto.md)
 - [CreateManyModelDto](docs/CreateManyModelDto.md)
 - [CreateManyModelJobDto](docs/CreateManyModelJobDto.md)
 - [CreateManyModelJobOutputDto](docs/CreateManyModelJobOutputDto.md)
 - [CreateManyModelPopulationDto](docs/CreateManyModelPopulationDto.md)
 - [CreateManyOrganizationDto](docs/CreateManyOrganizationDto.md)
 - [CreateManyOrganizationSettingDto](docs/CreateManyOrganizationSettingDto.md)
 - [CreateManyPopulationStoreDto](docs/CreateManyPopulationStoreDto.md)
 - [CreateManyProjectDto](docs/CreateManyProjectDto.md)
 - [CreateManyProjectMemberDto](docs/CreateManyProjectMemberDto.md)
 - [CreateManySchedulerDto](docs/CreateManySchedulerDto.md)
 - [CreateManyTaskDto](docs/CreateManyTaskDto.md)
 - [CreateManyTaskExecutionDto](docs/CreateManyTaskExecutionDto.md)
 - [CreateManyTaskExecutionStatusDto](docs/CreateManyTaskExecutionStatusDto.md)
 - [CreateManyTectonFeatureDto](docs/CreateManyTectonFeatureDto.md)
 - [CreateManyUserFavoriteDto](docs/CreateManyUserFavoriteDto.md)
 - [CreateManyWorkflowDto](docs/CreateManyWorkflowDto.md)
 - [CreateManyWorkflowExecutionDto](docs/CreateManyWorkflowExecutionDto.md)
 - [CreateManyWorkflowExecutionSpecDto](docs/CreateManyWorkflowExecutionSpecDto.md)
 - [CreateManyWorkflowTemplateDto](docs/CreateManyWorkflowTemplateDto.md)
 - [CreateModelDto](docs/CreateModelDto.md)
 - [CreateModelJobDto](docs/CreateModelJobDto.md)
 - [CreateModelJobOutputDto](docs/CreateModelJobOutputDto.md)
 - [CreateModelJobStatusDto](docs/CreateModelJobStatusDto.md)
 - [CreateModelPopulationDto](docs/CreateModelPopulationDto.md)
 - [CreateOrganizationDto](docs/CreateOrganizationDto.md)
 - [CreateOrganizationSettingDto](docs/CreateOrganizationSettingDto.md)
 - [CreatePopulationStoreDto](docs/CreatePopulationStoreDto.md)
 - [CreateProjectDto](docs/CreateProjectDto.md)
 - [CreateProjectMemberDto](docs/CreateProjectMemberDto.md)
 - [CreateSchedulerDto](docs/CreateSchedulerDto.md)
 - [CreateTaskDto](docs/CreateTaskDto.md)
 - [CreateTaskExecutionDto](docs/CreateTaskExecutionDto.md)
 - [CreateTaskExecutionStatusDto](docs/CreateTaskExecutionStatusDto.md)
 - [CreateTectonFeatureDto](docs/CreateTectonFeatureDto.md)
 - [CreateUserAuditTrailDto](docs/CreateUserAuditTrailDto.md)
 - [CreateUserFavoriteDto](docs/CreateUserFavoriteDto.md)
 - [CreateWorkflowDto](docs/CreateWorkflowDto.md)
 - [CreateWorkflowExecutionDto](docs/CreateWorkflowExecutionDto.md)
 - [CreateWorkflowExecutionSpecDto](docs/CreateWorkflowExecutionSpecDto.md)
 - [CreateWorkflowExecutionStatusDto](docs/CreateWorkflowExecutionStatusDto.md)
 - [CreateWorkflowTemplateDto](docs/CreateWorkflowTemplateDto.md)
 - [DataQuery](docs/DataQuery.md)
 - [DataQueryJoinedDatasetResponseDto](docs/DataQueryJoinedDatasetResponseDto.md)
 - [DataQueryResponseDto](docs/DataQueryResponseDto.md)
 - [DataStore](docs/DataStore.md)
 - [DataStoreResponseDto](docs/DataStoreResponseDto.md)
 - [DataTable](docs/DataTable.md)
 - [DataTableJoinedDatabaseResponseDto](docs/DataTableJoinedDatabaseResponseDto.md)
 - [DataTableJoinedDatasetResponseDto](docs/DataTableJoinedDatasetResponseDto.md)
 - [DataTableResponseDto](docs/DataTableResponseDto.md)
 - [Database](docs/Database.md)
 - [DatabaseJoinedDataTableResponseDto](docs/DatabaseJoinedDataTableResponseDto.md)
 - [DatabaseResponseDto](docs/DatabaseResponseDto.md)
 - [Dataset](docs/Dataset.md)
 - [DatasetColumn](docs/DatasetColumn.md)
 - [DatasetColumnJoinedDatasetResponseDto](docs/DatasetColumnJoinedDatasetResponseDto.md)
 - [DatasetColumnResponseDto](docs/DatasetColumnResponseDto.md)
 - [DatasetJoinedDataQueryResponseDto](docs/DatasetJoinedDataQueryResponseDto.md)
 - [DatasetJoinedDatasetColumnResponseDto](docs/DatasetJoinedDatasetColumnResponseDto.md)
 - [DatasetResponseDto](docs/DatasetResponseDto.md)
 - [DatasetsuploadlargecompleteParts](docs/DatasetsuploadlargecompleteParts.md)
 - [Feature](docs/Feature.md)
 - [FeatureCategory](docs/FeatureCategory.md)
 - [FeatureJoinedFeatureSubCategoryJoinedFeatureCategoryResponseDto](docs/FeatureJoinedFeatureSubCategoryJoinedFeatureCategoryResponseDto.md)
 - [FeatureJoinedFeatureSubCategoryResponseDto](docs/FeatureJoinedFeatureSubCategoryResponseDto.md)
 - [FeatureJoinedModelPopulationResponseDto](docs/FeatureJoinedModelPopulationResponseDto.md)
 - [FeatureJoinedOrganizationFeatureExclusionResponseDto](docs/FeatureJoinedOrganizationFeatureExclusionResponseDto.md)
 - [FeatureResponseDto](docs/FeatureResponseDto.md)
 - [FeatureService](docs/FeatureService.md)
 - [FeatureServiceJoinedFeatureTableJoinedTectonFeatureResponseDto](docs/FeatureServiceJoinedFeatureTableJoinedTectonFeatureResponseDto.md)
 - [FeatureServiceJoinedFeatureTableResponseDto](docs/FeatureServiceJoinedFeatureTableResponseDto.md)
 - [FeatureServiceJoinedFeatureViewJoinedTectonFeatureResponseDto](docs/FeatureServiceJoinedFeatureViewJoinedTectonFeatureResponseDto.md)
 - [FeatureServiceJoinedFeatureViewResponseDto](docs/FeatureServiceJoinedFeatureViewResponseDto.md)
 - [FeatureServiceResponseDto](docs/FeatureServiceResponseDto.md)
 - [FeatureStore](docs/FeatureStore.md)
 - [FeatureStoreResponseDto](docs/FeatureStoreResponseDto.md)
 - [FeatureSubCategory](docs/FeatureSubCategory.md)
 - [FeatureTable](docs/FeatureTable.md)
 - [FeatureTableJoinedFeatureServiceResponseDto](docs/FeatureTableJoinedFeatureServiceResponseDto.md)
 - [FeatureTableJoinedTectonFeatureResponseDto](docs/FeatureTableJoinedTectonFeatureResponseDto.md)
 - [FeatureTableResponseDto](docs/FeatureTableResponseDto.md)
 - [FeatureView](docs/FeatureView.md)
 - [FeatureViewJoinedFeatureServiceResponseDto](docs/FeatureViewJoinedFeatureServiceResponseDto.md)
 - [FeatureViewJoinedTectonFeatureResponseDto](docs/FeatureViewJoinedTectonFeatureResponseDto.md)
 - [FeatureViewResponseDto](docs/FeatureViewResponseDto.md)
 - [GeographicCounts](docs/GeographicCounts.md)
 - [GeographicQueries](docs/GeographicQueries.md)
 - [GetManyCohortResponseDto](docs/GetManyCohortResponseDto.md)
 - [GetManyDataQueryResponseDto](docs/GetManyDataQueryResponseDto.md)
 - [GetManyDataStoreResponseDto](docs/GetManyDataStoreResponseDto.md)
 - [GetManyDataTableResponseDto](docs/GetManyDataTableResponseDto.md)
 - [GetManyDatabaseResponseDto](docs/GetManyDatabaseResponseDto.md)
 - [GetManyDatasetColumnResponseDto](docs/GetManyDatasetColumnResponseDto.md)
 - [GetManyDatasetResponseDto](docs/GetManyDatasetResponseDto.md)
 - [GetManyFeatureResponseDto](docs/GetManyFeatureResponseDto.md)
 - [GetManyFeatureServiceResponseDto](docs/GetManyFeatureServiceResponseDto.md)
 - [GetManyFeatureStoreResponseDto](docs/GetManyFeatureStoreResponseDto.md)
 - [GetManyFeatureTableResponseDto](docs/GetManyFeatureTableResponseDto.md)
 - [GetManyFeatureViewResponseDto](docs/GetManyFeatureViewResponseDto.md)
 - [GetManyModelJobOutputResponseDto](docs/GetManyModelJobOutputResponseDto.md)
 - [GetManyModelJobResponseDto](docs/GetManyModelJobResponseDto.md)
 - [GetManyModelJobStatusResponseDto](docs/GetManyModelJobStatusResponseDto.md)
 - [GetManyModelPopulationResponseDto](docs/GetManyModelPopulationResponseDto.md)
 - [GetManyModelResponseDto](docs/GetManyModelResponseDto.md)
 - [GetManyOrganizationResponseDto](docs/GetManyOrganizationResponseDto.md)
 - [GetManyOrganizationSettingResponseDto](docs/GetManyOrganizationSettingResponseDto.md)
 - [GetManyPopulationStoreResponseDto](docs/GetManyPopulationStoreResponseDto.md)
 - [GetManyProjectMemberResponseDto](docs/GetManyProjectMemberResponseDto.md)
 - [GetManyProjectResponseDto](docs/GetManyProjectResponseDto.md)
 - [GetManySchedulerResponseDto](docs/GetManySchedulerResponseDto.md)
 - [GetManyTaskExecutionResponseDto](docs/GetManyTaskExecutionResponseDto.md)
 - [GetManyTaskExecutionStatusResponseDto](docs/GetManyTaskExecutionStatusResponseDto.md)
 - [GetManyTaskResponseDto](docs/GetManyTaskResponseDto.md)
 - [GetManyTectonFeatureResponseDto](docs/GetManyTectonFeatureResponseDto.md)
 - [GetManyUserAuditTrailResponseDto](docs/GetManyUserAuditTrailResponseDto.md)
 - [GetManyUserFavoriteResponseDto](docs/GetManyUserFavoriteResponseDto.md)
 - [GetManyWorkflowExecutionResponseDto](docs/GetManyWorkflowExecutionResponseDto.md)
 - [GetManyWorkflowExecutionSpecResponseDto](docs/GetManyWorkflowExecutionSpecResponseDto.md)
 - [GetManyWorkflowExecutionStatusResponseDto](docs/GetManyWorkflowExecutionStatusResponseDto.md)
 - [GetManyWorkflowResponseDto](docs/GetManyWorkflowResponseDto.md)
 - [GetManyWorkflowTemplateResponseDto](docs/GetManyWorkflowTemplateResponseDto.md)
 - [InterventionDefinition](docs/InterventionDefinition.md)
 - [Json](docs/Json.md)
 - [Model](docs/Model.md)
 - [ModelJob](docs/ModelJob.md)
 - [ModelJobConfig](docs/ModelJobConfig.md)
 - [ModelJobEvent](docs/ModelJobEvent.md)
 - [ModelJobJoinedCohortResponseDto](docs/ModelJobJoinedCohortResponseDto.md)
 - [ModelJobJoinedDataQueryResponseDto](docs/ModelJobJoinedDataQueryResponseDto.md)
 - [ModelJobJoinedDatasetResponseDto](docs/ModelJobJoinedDatasetResponseDto.md)
 - [ModelJobJoinedFeatureSubCategoryResponseDto](docs/ModelJobJoinedFeatureSubCategoryResponseDto.md)
 - [ModelJobJoinedModelJobOutputResponseDto](docs/ModelJobJoinedModelJobOutputResponseDto.md)
 - [ModelJobJoinedModelJobStatusResponseDto](docs/ModelJobJoinedModelJobStatusResponseDto.md)
 - [ModelJobJoinedModelPopulationJoinedCohortDefinitionJoinedPeriodDefinitionResponseDto](docs/ModelJobJoinedModelPopulationJoinedCohortDefinitionJoinedPeriodDefinitionResponseDto.md)
 - [ModelJobJoinedModelPopulationJoinedCohortDefinitionResponseDto](docs/ModelJobJoinedModelPopulationJoinedCohortDefinitionResponseDto.md)
 - [ModelJobJoinedModelPopulationJoinedDataQueryJoinedDatasetResponseDto](docs/ModelJobJoinedModelPopulationJoinedDataQueryJoinedDatasetResponseDto.md)
 - [ModelJobJoinedModelPopulationJoinedDataQueryResponseDto](docs/ModelJobJoinedModelPopulationJoinedDataQueryResponseDto.md)
 - [ModelJobJoinedModelPopulationJoinedInterventionDefinitionResponseDto](docs/ModelJobJoinedModelPopulationJoinedInterventionDefinitionResponseDto.md)
 - [ModelJobJoinedModelPopulationJoinedOutcomeDefinitionResponseDto](docs/ModelJobJoinedModelPopulationJoinedOutcomeDefinitionResponseDto.md)
 - [ModelJobJoinedModelPopulationJoinedTectonFeatureResponseDto](docs/ModelJobJoinedModelPopulationJoinedTectonFeatureResponseDto.md)
 - [ModelJobJoinedModelPopulationResponseDto](docs/ModelJobJoinedModelPopulationResponseDto.md)
 - [ModelJobJoinedModelResponseDto](docs/ModelJobJoinedModelResponseDto.md)
 - [ModelJobJoinedProjectResponseDto](docs/ModelJobJoinedProjectResponseDto.md)
 - [ModelJobOutput](docs/ModelJobOutput.md)
 - [ModelJobOutputJoinedDatasetResponseDto](docs/ModelJobOutputJoinedDatasetResponseDto.md)
 - [ModelJobOutputJoinedModelJobJoinedProjectResponseDto](docs/ModelJobOutputJoinedModelJobJoinedProjectResponseDto.md)
 - [ModelJobOutputJoinedModelJobResponseDto](docs/ModelJobOutputJoinedModelJobResponseDto.md)
 - [ModelJobOutputResponseDto](docs/ModelJobOutputResponseDto.md)
 - [ModelJobResponseDto](docs/ModelJobResponseDto.md)
 - [ModelJobStatus](docs/ModelJobStatus.md)
 - [ModelJobStatusJoinedModelJobJoinedProjectResponseDto](docs/ModelJobStatusJoinedModelJobJoinedProjectResponseDto.md)
 - [ModelJobStatusJoinedModelJobResponseDto](docs/ModelJobStatusJoinedModelJobResponseDto.md)
 - [ModelJobStatusResponseDto](docs/ModelJobStatusResponseDto.md)
 - [ModelJobStatusUpdateProjectIdDto](docs/ModelJobStatusUpdateProjectIdDto.md)
 - [ModelJoinedCohortJoinedModelJobResponseDto](docs/ModelJoinedCohortJoinedModelJobResponseDto.md)
 - [ModelJoinedCohortResponseDto](docs/ModelJoinedCohortResponseDto.md)
 - [ModelJoinedModelJobJoinedCohortResponseDto](docs/ModelJoinedModelJobJoinedCohortResponseDto.md)
 - [ModelJoinedModelJobJoinedDatasetResponseDto](docs/ModelJoinedModelJobJoinedDatasetResponseDto.md)
 - [ModelJoinedModelJobJoinedFeatureSubCategoryResponseDto](docs/ModelJoinedModelJobJoinedFeatureSubCategoryResponseDto.md)
 - [ModelJoinedModelJobResponseDto](docs/ModelJoinedModelJobResponseDto.md)
 - [ModelJoinedModelOutputDetailsResponseDto](docs/ModelJoinedModelOutputDetailsResponseDto.md)
 - [ModelJoinedProjectResponseDto](docs/ModelJoinedProjectResponseDto.md)
 - [ModelJoinedUserFavoriteResponseDto](docs/ModelJoinedUserFavoriteResponseDto.md)
 - [ModelOutputDetails](docs/ModelOutputDetails.md)
 - [ModelPopulation](docs/ModelPopulation.md)
 - [ModelPopulationJoinedCohortDefinitionJoinedPeriodDefinitionResponseDto](docs/ModelPopulationJoinedCohortDefinitionJoinedPeriodDefinitionResponseDto.md)
 - [ModelPopulationJoinedCohortDefinitionResponseDto](docs/ModelPopulationJoinedCohortDefinitionResponseDto.md)
 - [ModelPopulationJoinedCohortResultsResponseDto](docs/ModelPopulationJoinedCohortResultsResponseDto.md)
 - [ModelPopulationJoinedDataQueryJoinedDatasetResponseDto](docs/ModelPopulationJoinedDataQueryJoinedDatasetResponseDto.md)
 - [ModelPopulationJoinedDataQueryResponseDto](docs/ModelPopulationJoinedDataQueryResponseDto.md)
 - [ModelPopulationJoinedFeatureResponseDto](docs/ModelPopulationJoinedFeatureResponseDto.md)
 - [ModelPopulationJoinedInterventionDefinitionResponseDto](docs/ModelPopulationJoinedInterventionDefinitionResponseDto.md)
 - [ModelPopulationJoinedModelJobJoinedModelResponseDto](docs/ModelPopulationJoinedModelJobJoinedModelResponseDto.md)
 - [ModelPopulationJoinedModelJobResponseDto](docs/ModelPopulationJoinedModelJobResponseDto.md)
 - [ModelPopulationJoinedOutcomeDefinitionResponseDto](docs/ModelPopulationJoinedOutcomeDefinitionResponseDto.md)
 - [ModelPopulationJoinedTectonFeatureResponseDto](docs/ModelPopulationJoinedTectonFeatureResponseDto.md)
 - [ModelPopulationResponseDto](docs/ModelPopulationResponseDto.md)
 - [ModelResponseDto](docs/ModelResponseDto.md)
 - [Object](docs/Object.md)
 - [Organization](docs/Organization.md)
 - [OrganizationFeatureCategoryExclusion](docs/OrganizationFeatureCategoryExclusion.md)
 - [OrganizationFeatureExclusion](docs/OrganizationFeatureExclusion.md)
 - [OrganizationResponseDto](docs/OrganizationResponseDto.md)
 - [OrganizationSetting](docs/OrganizationSetting.md)
 - [OrganizationSettingResponseDto](docs/OrganizationSettingResponseDto.md)
 - [OutcomeDefinition](docs/OutcomeDefinition.md)
 - [PeriodDefinition](docs/PeriodDefinition.md)
 - [PersonSet](docs/PersonSet.md)
 - [PipelineConfig](docs/PipelineConfig.md)
 - [Population](docs/Population.md)
 - [PopulationStore](docs/PopulationStore.md)
 - [PopulationStoreResponseDto](docs/PopulationStoreResponseDto.md)
 - [Project](docs/Project.md)
 - [ProjectJoinedModelJoinedCohortResponseDto](docs/ProjectJoinedModelJoinedCohortResponseDto.md)
 - [ProjectJoinedModelResponseDto](docs/ProjectJoinedModelResponseDto.md)
 - [ProjectJoinedProjectResponseDto](docs/ProjectJoinedProjectResponseDto.md)
 - [ProjectJoinedUserFavoriteResponseDto](docs/ProjectJoinedUserFavoriteResponseDto.md)
 - [ProjectMember](docs/ProjectMember.md)
 - [ProjectMemberJoinedProjectResponseDto](docs/ProjectMemberJoinedProjectResponseDto.md)
 - [ProjectMemberResponseDto](docs/ProjectMemberResponseDto.md)
 - [ProjectResponseDto](docs/ProjectResponseDto.md)
 - [Scheduler](docs/Scheduler.md)
 - [SchedulerJoinedWorkflowResponseDto](docs/SchedulerJoinedWorkflowResponseDto.md)
 - [SchedulerResponseDto](docs/SchedulerResponseDto.md)
 - [SelectExpression](docs/SelectExpression.md)
 - [StateData](docs/StateData.md)
 - [Task](docs/Task.md)
 - [TaskExecution](docs/TaskExecution.md)
 - [TaskExecutionJoinedTaskResponseDto](docs/TaskExecutionJoinedTaskResponseDto.md)
 - [TaskExecutionJoinedWorkflowExecutionResponseDto](docs/TaskExecutionJoinedWorkflowExecutionResponseDto.md)
 - [TaskExecutionResponseDto](docs/TaskExecutionResponseDto.md)
 - [TaskExecutionStatus](docs/TaskExecutionStatus.md)
 - [TaskExecutionStatusJoinedTaskExecutionJoinedWorkflowExecutionResponseDto](docs/TaskExecutionStatusJoinedTaskExecutionJoinedWorkflowExecutionResponseDto.md)
 - [TaskExecutionStatusJoinedTaskExecutionResponseDto](docs/TaskExecutionStatusJoinedTaskExecutionResponseDto.md)
 - [TaskExecutionStatusResponseDto](docs/TaskExecutionStatusResponseDto.md)
 - [TaskInputs](docs/TaskInputs.md)
 - [TaskOutputs](docs/TaskOutputs.md)
 - [TaskResponseDto](docs/TaskResponseDto.md)
 - [TectonFeature](docs/TectonFeature.md)
 - [TectonFeatureJoinedFeatureTableResponseDto](docs/TectonFeatureJoinedFeatureTableResponseDto.md)
 - [TectonFeatureJoinedFeatureViewResponseDto](docs/TectonFeatureJoinedFeatureViewResponseDto.md)
 - [TectonFeatureJoinedModelPopulationResponseDto](docs/TectonFeatureJoinedModelPopulationResponseDto.md)
 - [TectonFeatureResponseDto](docs/TectonFeatureResponseDto.md)
 - [UpdateCohortDto](docs/UpdateCohortDto.md)
 - [UpdateDataQueryDto](docs/UpdateDataQueryDto.md)
 - [UpdateDataStoreDto](docs/UpdateDataStoreDto.md)
 - [UpdateDataTableDto](docs/UpdateDataTableDto.md)
 - [UpdateDatabaseDto](docs/UpdateDatabaseDto.md)
 - [UpdateDatasetColumnDto](docs/UpdateDatasetColumnDto.md)
 - [UpdateDatasetDto](docs/UpdateDatasetDto.md)
 - [UpdateFeatureDto](docs/UpdateFeatureDto.md)
 - [UpdateFeatureServiceDto](docs/UpdateFeatureServiceDto.md)
 - [UpdateFeatureStoreDto](docs/UpdateFeatureStoreDto.md)
 - [UpdateFeatureTableDto](docs/UpdateFeatureTableDto.md)
 - [UpdateFeatureViewDto](docs/UpdateFeatureViewDto.md)
 - [UpdateModelDto](docs/UpdateModelDto.md)
 - [UpdateModelJobDto](docs/UpdateModelJobDto.md)
 - [UpdateModelJobOutputDto](docs/UpdateModelJobOutputDto.md)
 - [UpdateModelJobStatusDto](docs/UpdateModelJobStatusDto.md)
 - [UpdateModelPopulationDto](docs/UpdateModelPopulationDto.md)
 - [UpdateOrganizationDto](docs/UpdateOrganizationDto.md)
 - [UpdateOrganizationSettingDto](docs/UpdateOrganizationSettingDto.md)
 - [UpdatePopulationStoreDto](docs/UpdatePopulationStoreDto.md)
 - [UpdateProjectDto](docs/UpdateProjectDto.md)
 - [UpdateProjectMemberDto](docs/UpdateProjectMemberDto.md)
 - [UpdateSchedulerDto](docs/UpdateSchedulerDto.md)
 - [UpdateTaskDto](docs/UpdateTaskDto.md)
 - [UpdateTaskExecutionDto](docs/UpdateTaskExecutionDto.md)
 - [UpdateTaskExecutionStatusDto](docs/UpdateTaskExecutionStatusDto.md)
 - [UpdateTectonFeatureDto](docs/UpdateTectonFeatureDto.md)
 - [UpdateUserAuditTrailDto](docs/UpdateUserAuditTrailDto.md)
 - [UpdateUserDto](docs/UpdateUserDto.md)
 - [UpdateUserFavoriteDto](docs/UpdateUserFavoriteDto.md)
 - [UpdateWorkflowDto](docs/UpdateWorkflowDto.md)
 - [UpdateWorkflowExecutionDto](docs/UpdateWorkflowExecutionDto.md)
 - [UpdateWorkflowExecutionSpecDto](docs/UpdateWorkflowExecutionSpecDto.md)
 - [UpdateWorkflowExecutionStatusDto](docs/UpdateWorkflowExecutionStatusDto.md)
 - [UpdateWorkflowTemplateDto](docs/UpdateWorkflowTemplateDto.md)
 - [UserAuditTrailResponseDto](docs/UserAuditTrailResponseDto.md)
 - [UserFavorite](docs/UserFavorite.md)
 - [UserFavoriteJoinedModelJoinedProjectResponseDto](docs/UserFavoriteJoinedModelJoinedProjectResponseDto.md)
 - [UserFavoriteJoinedModelResponseDto](docs/UserFavoriteJoinedModelResponseDto.md)
 - [UserFavoriteResponseDto](docs/UserFavoriteResponseDto.md)
 - [Workflow](docs/Workflow.md)
 - [WorkflowExecution](docs/WorkflowExecution.md)
 - [WorkflowExecutionResponseDto](docs/WorkflowExecutionResponseDto.md)
 - [WorkflowExecutionSpec](docs/WorkflowExecutionSpec.md)
 - [WorkflowExecutionSpecJoinedWorkflowExecutionResponseDto](docs/WorkflowExecutionSpecJoinedWorkflowExecutionResponseDto.md)
 - [WorkflowExecutionSpecResponseDto](docs/WorkflowExecutionSpecResponseDto.md)
 - [WorkflowExecutionStatus](docs/WorkflowExecutionStatus.md)
 - [WorkflowExecutionStatusJoinedWorkflowExecutionResponseDto](docs/WorkflowExecutionStatusJoinedWorkflowExecutionResponseDto.md)
 - [WorkflowExecutionStatusResponseDto](docs/WorkflowExecutionStatusResponseDto.md)
 - [WorkflowJoinedSchedulerResponseDto](docs/WorkflowJoinedSchedulerResponseDto.md)
 - [WorkflowJoinedWorkflowExecutionResponseDto](docs/WorkflowJoinedWorkflowExecutionResponseDto.md)
 - [WorkflowJoinedWorkflowTemplateResponseDto](docs/WorkflowJoinedWorkflowTemplateResponseDto.md)
 - [WorkflowResponseDto](docs/WorkflowResponseDto.md)
 - [WorkflowTemplate](docs/WorkflowTemplate.md)
 - [WorkflowTemplateDefinition](docs/WorkflowTemplateDefinition.md)
 - [WorkflowTemplateParameters](docs/WorkflowTemplateParameters.md)
 - [WorkflowTemplateResponseDto](docs/WorkflowTemplateResponseDto.md)
 - [ZipData](docs/ZipData.md)

## Documentation For Authorization


## api_key

- **Type**: API key
- **API key parameter name**: Api-Key
- **Location**: HTTP header


## Author


